//#############################################################################
//
// FILE:   ttplpfc.c
//
// TITLE: This is the solution file.
//
//#############################################################################
// $TI Release: TIDA_010062 v2.02.00.00 $
// $Release Date: Fri Oct  6 19:11:54 CDT 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#include <ttplpfc.h>

/*****************************Global Variables*****************************/
#pragma SET_DATA_SECTION("controlVariables")

//
// RAMP to generate forced angle when grid is not present
//
TTPLPFC_RAMP TTPLPFC_rgen;

//
//PI parameters
//
volatile TTPLPFC_GI TTPLPFC_gi;
volatile TTPLPFC_GV TTPLPFC_gv;

//
//SPLL
//
SPLL_1PH_SOGI TTPLPFC_spll1;
SPLL_1PH_NOTCH TTPLPFC_spll2;
SPLL_1PH_SOGI_FLL TTPLPFC_spll3;
TTPLPFC_NOTCH_2P2Z TTPLPFC_notch1, TTPLPFC_notch2;

//
// Sine analyzer block for RMS Volt, Curr and Power measurements
//
volatile POWER_MEAS_SINE_ANALYZER TTPLPFC_sine_mains;

//
// Display Values
//
volatile float32_t TTPLPFC_guiVbus_Volts;
float32_t TTPLPFC_guiVbusMax_Volts;
volatile float32_t TTPLPFC_guiVrms_Volts;
float32_t TTPLPFC_guiACFreq_Hz;
float32_t TTPLPFC_guiPrms_W;
float32_t TTPLPFC_guiIrms_Amps;
float32_t TTPLPFC_guiVavg_Volts;
float32_t TTPLPFC_guiFreqAvg_Hz;
float32_t TTPLPFC_guiVema_Volts;
float32_t TTPLPFC_ac_volRmsEma_sensed_Volts;
float32_t TTPLPFC_guiVin_Volts;

//
// 10 corresponds to 100ns dead time
//
uint32_t TTPLPFC_dbRED_SetValue_ticks;
uint32_t TTPLPFC_dbRED_SetValue_Temp_ticks;
volatile uint32_t TTPLPFC_dbFED_SetValue_ticks;
uint32_t TTPLPFC_dbRED_Min_ticks;
uint32_t TTPLPFC_dbRED_Max_ticks;

//
// AC Current Measurement
//
volatile float32_t TTPLPFC_ac_cur_sensed_pu, TTPLPFC_iLVrefMeas_pu;
volatile float32_t TTPLPFC_ac_cur_ref_pu;
float32_t TTPLPFC_iLMeasScaled_Amps;
float32_t TTPLPFC_iLMeasOffset_pu;
float32_t TTPLPFC_ac_cur_ref_inst_pu, TTPLPFC_ac_cur_ref_inst_prev_pu;


//
//Output Voltage measurement
//
volatile float32_t TTPLPFC_vBus_sensed_pu;
float32_t TTPLPFC_vBusMeasOffset_pu;
float32_t TTPLPFC_vBusRef_pu;
float32_t TTPLPFC_vBus_sensedFiltered_notch1;
float32_t TTPLPFC_vBus_sensedFiltered_notch2;

//
//Input voltage measurement
//
volatile float32_t TTPLPFC_ac_L_sensed_pu;
volatile float32_t TTPLPFC_ac_N_sensed_pu, TTPLPFC_ac_vol_sensed_pu;
float32_t TTPLPFC_vACLMeasOffset_pu;
float32_t TTPLPFC_vACNMeasOffset_pu, TTPLPFC_vACMeasOffset_pu;

//
//Duty relation.
//
volatile float32_t TTPLPFC_dutyPU, TTPLPFC_dutyPU_DC;
volatile float32_t TTPLPFC_thetaOffset_pu;

//
//Control flags.
//
int32_t TTPLPFC_closeGiLoop, TTPLPFC_closeGvLoop;
volatile int32_t TTPLPFC_relayConnect;
int32_t TTPLPFC_autoStartSlew, TTPLPFC_firstTimeGvLoop;

//
// Flags for detecting ZCD
//
volatile float32_t TTPLPFC_acSine;
float32_t TTPLPFC_acSine_Prev;
float32_t TTPLPFC_threshold_PZC1, TTPLPFC_threshold_PZC2;
float32_t TTPLPFC_threshold_NZC1, TTPLPFC_threshold_NZC2;

//
// 1 if using non linear voltage loop, 0 otherwise
//
uint32_t TTPLPFC_nonLinearVoltageLoopFlag;

//
//Filtered DC&AC voltage measurement
//
float32_t TTPLPFC_vBusAvg_pu;
float32_t TTPLPFC_vACRmsMeasAvg_pu;

//
//inductor_voltage_drop_feedforward
//
float32_t TTPLPFC_inductor_voltage_drop_feedforward;

//
//voltage set point
//
float32_t TTPLPFC_vBusRefSlewed_pu;

//
//Other display Values
//
float32_t TTPLPFC_guiIL_Amps;
float32_t TTPLPFC_guiPowerFactor;
float32_t TTPLPFC_guiVA_VA;

//
//Soft start in pwmSwState switch
//
float32_t TTPLPFC_softStartDuty_ticks;
int32_t TTPLPFC_stateSlew = 0;
int32_t TTPLPFC_stateSlewMax;
volatile uint32_t TTPLPFC_softStartDeadBandFED_ticks;

//
//Controller output.
//
volatile float32_t TTPLPFC_gi_out;
float32_t TTPLPFC_gv_out, TTPLPFC_gi_pi_ki;

//
//Status flags.
//
TTPLPFC_Lab_EnumType TTPLPFC_lab;
TTPLPFC_boardState TTPLPFC_board_State;
TTPLPFC_boardStatus TTPLPFC_board_Status;
TTPLPFC_pwmSwState TTPLPFC_pwm_SwState;

//
//Filter BUS voltage sensed result.
//
volatile float32_t TTPLPFC_vBusMeasBuff_pu[10];
float32_t TTPLPFC_vBusMeasFiltered_pu;
int32_t TTPLPFC_vBusMeasBuffIndex = 0;

//
//SPLL result. Vin direction.
//
float32_t TTPLPFC_spll_sine, TTPLPFC_spll_cosine;
int32_t TTPLPFC_ac_sign_filtered;

// FSI ISR status flag
volatile uint32_t TTPLPFC_fsiTxInt1Received, TTPLPFC_fsiTxInt2Received;
volatile uint32_t TTPLPFC_fsiRxInt1Received, TTPLPFC_fsiRxInt2Received;

//
// Globals, these are not config parameters, user are not required to edit them
//
uint16_t TTPLPFC_txEventSts, TTPLPFC_rxEventSts;

//
//Voltage loop flag.
//
float32_t TTPLPFC_vBusError_pu;

float32_t TTPLPFC_phase2ScaleFactor;

//
//LLC startup flag.
//
int16_t TTPLPFC_llcStartupFlag;
uint16_t TTPLPFC_Handshake_Complete_Flag;

//
//LLC shutdown flag.
//
int16_t TTPLPFC_llcShutdownFlag;

//
//Relay control.
//
uint16_t TTPLPFC_relay_count;

//
// Variables used to calibrate measurement offsets
// Offset filter coefficient K1: 0.05/(T+0.05);
//
float32_t TTPLPFC_k1;

//
//Offset filter coefficient K2: T/(T+0.05)
//
float32_t TTPLPFC_k2;


volatile int16_t TTPLPFC_highPowerTrans_flag;
#pragma SET_DATA_SECTION()

//
//Datalogger
//
DLOG_4CH TTPLPFC_dLog1;
float32_t TTPLPFC_dBuff1[100], TTPLPFC_dBuff2[100];
float32_t TTPLPFC_dBuff3[100], TTPLPFC_dBuff4[100];
float32_t TTPLPFC_dVal1, TTPLPFC_dVal2, TTPLPFC_dVal3, TTPLPFC_dVal4;

//
//--- SFRA Related Variables ---
//
#if TTPLPFC_SFRA_TYPE != TTPLPFC_SFRA_DISABLED
float32_t TTPLPFC_plantMagVect[TTPLPFC_SFRA_FREQ_LENGTH];
float32_t TTPLPFC_plantPhaseVect[TTPLPFC_SFRA_FREQ_LENGTH];
float32_t TTPLPFC_olMagVect[TTPLPFC_SFRA_FREQ_LENGTH];
float32_t TTPLPFC_olPhaseVect[TTPLPFC_SFRA_FREQ_LENGTH];
float32_t TTPLPFC_freqVect[TTPLPFC_SFRA_FREQ_LENGTH];
#endif

SFRA_F32 TTPLPFC_sfra1;
int16_t i;
volatile int16_t TTPLPFC_initializationFlag;

//
//User monitoring variables.
//
volatile float32_t *TTPLPFC_iqGraphIdTab1[5] = {
&(TTPLPFC_acSine), /*0*/&(TTPLPFC_ac_vol_sensed_pu),
/*1*/&(TTPLPFC_dutyPU ), /*2*/&(TTPLPFC_spll_sine),
/*3*/&(TTPLPFC_acSine), /*4*/};
uint16_t TTPLPFC_uGraphID = 1;
uint16_t TTPLPFC_uGraphID2 = 2;
uint16_t TTPLPFC_IsrTicker = 0;
uint16_t TTPLPFC_usShowCnt = 0;
uint16_t TTPLPFC_usShowDiv = 40;
float32_t TTPLPFC_Watchvalue[100];
float32_t TTPLPFC_Watchvalue1[100];

//
//User debug graph array.
//
#if TTPLPFC_DEBUG_CHIP == F28004X
#pragma SET_DATA_SECTION("graphArray1")
float32_t TTPLPFC_graphArrayWatchValue1[1600];
uint16_t TTPLPFC_graphArrayWatchValueindex1;
uint16_t TTPLPFC_faultTriggerFlag1;//0 No fault 1 Fault
#pragma SET_DATA_SECTION()
#pragma SET_DATA_SECTION("graphArray3")
float32_t TTPLPFC_graphArrayWatchValue2[1600];
#pragma SET_DATA_SECTION()
#pragma SET_DATA_SECTION("graphArray2")
float32_t TTPLPFC_graphArrayWatchValue3[2000];
float32_t TTPLPFC_graphArrayWatchValue4[2000];
uint16_t TTPLPFC_graphArrayWatchValueindex2;
uint16_t TTPLPFC_faultTriggerFlag2;//0 No fault 1 Fault
#pragma SET_DATA_SECTION()
#endif


void TTPLPFC_globalVariablesInit(void)
{
    /*Open loop check when TTPLPFC_LAB=1. Generate ramp wave.*/
    RAMPGEN_reset(&TTPLPFC_rgen);
    RAMPGEN_config(&TTPLPFC_rgen,
                   TTPLPFC_CONTROL_ISR_FREQUENCY,
                   TTPLPFC_AC_FREQ);

    /*PI parameter for current and voltage loop*/
    #if TTPLPFC_CONTROL_RUNNING_ON == C28x_CORE
    TTPLPFC_gi.Kp = TTPLPFC_GI_PI_KP;
    TTPLPFC_gi.Ki = TTPLPFC_GI_PI_KI;
    #endif
    #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
    TTPLPFC_gi.Kp = TTPLPFC_GI_PI_KP_CLAL;
    TTPLPFC_gi.Ki = TTPLPFC_GI_PI_KI_CLAL;
    #endif
    TTPLPFC_gi.Umax = TTPLPFC_GI_PI_MAX;
    TTPLPFC_gi.Umin = TTPLPFC_GI_PI_MIN;
    TTPLPFC_gi.i10 = 0;
    TTPLPFC_gi.i6 = 0;
    TTPLPFC_gi_pi_ki = TTPLPFC_GI_PI_KI;

    TTPLPFC_gv.Ki = TTPLPFC_GV_PI_KI;
    TTPLPFC_gv.Kp = TTPLPFC_GV_PI_KP;
    TTPLPFC_gv.Umax = TTPLPFC_GV_PI_MAX;
    TTPLPFC_gv.Umin = TTPLPFC_GV_PI_MIN;
    TTPLPFC_gv.i10 = 0;
    TTPLPFC_gv.i6 = 0;

    /*SPLL parameters. Use TTPLPFC_SPLL_METHOD_SELECT to select PLL method*/
    SPLL_1PH_SOGI_reset(&TTPLPFC_spll1);
    SPLL_1PH_SOGI_config(&TTPLPFC_spll1,
                         TTPLPFC_AC_FREQ,
                         TTPLPFC_CONTROL_ISR_FREQUENCY,
                         (float32_t)(222.2862),
                         (float32_t)(-222.034));

    SPLL_1PH_NOTCH_reset(&TTPLPFC_spll2);
    SPLL_1PH_NOTCH_config(&TTPLPFC_spll2,
                          TTPLPFC_AC_FREQ,
                          TTPLPFC_CONTROL_ISR_FREQUENCY,
                          (float32_t)(222.2862),
                          (float32_t)(-222.034),
                          (float32_t) 0.25,
                          (float32_t) 0.00001);

    SPLL_1PH_SOGI_FLL_reset(&TTPLPFC_spll3);
    SPLL_1PH_SOGI_FLL_config(&TTPLPFC_spll3,
                             TTPLPFC_AC_FREQ,
                             TTPLPFC_CONTROL_ISR_FREQUENCY,
                             (float32_t)(222.2862),
                             (float32_t)(-222.034),
                             (float32_t) 0.5,
                             (float32_t) 20000);

    /*Sine analyzer initialization*/
    POWER_MEAS_SINE_ANALYZER_reset(&TTPLPFC_sine_mains);
    POWER_MEAS_SINE_ANALYZER_config(&TTPLPFC_sine_mains,
                                    TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY,
                                    (float32_t)0.08,
                                    (float32_t)GRID_MAX_FREQ,
                                    (float32_t)GRID_MIN_FREQ);
    /*2nd order Direct Form 2 controller processing sensed BUS voltage signal*/
    computeNotchFltrCoeff(&TTPLPFC_notch1,
                          (float32_t)(TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY),
                          (float32_t)(TTPLPFC_AC_FREQ * 2.0f) ,
                          0.25f, 0.00001f);
    computeNotchFltrCoeff(&TTPLPFC_notch2,
                          (float32_t)(TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY),
                          (float32_t)(TTPLPFC_AC_FREQ * 2.0f) ,
                          0.25f, 0.00001f);
    TTPLPFC_notch1.x1 = 0;
    TTPLPFC_notch1.x2 = 0;
    TTPLPFC_notch2.x1 = 0;
    TTPLPFC_notch2.x2 = 0;

    /*Data log: graphically observe system variables */
    DLOG_4CH_reset(&TTPLPFC_dLog1);
    DLOG_4CH_config(&TTPLPFC_dLog1,
                    &TTPLPFC_dVal1, &TTPLPFC_dVal2,
                    &TTPLPFC_dVal3, &TTPLPFC_dVal4,
                    TTPLPFC_dBuff1, TTPLPFC_dBuff2,
                    TTPLPFC_dBuff3, TTPLPFC_dBuff4,
                    100, 0.1f, 5);

    /*Gui Variables initialize*/
    TTPLPFC_guiVbus_Volts = 0;
    TTPLPFC_guiACFreq_Hz = 0;
    TTPLPFC_guiPrms_W = 0;
    TTPLPFC_guiIrms_Amps = 0;
    TTPLPFC_guiVrms_Volts = 0;
    TTPLPFC_guiVavg_Volts = 0;
    TTPLPFC_guiFreqAvg_Hz = 0;
    TTPLPFC_guiVema_Volts = 0;
    TTPLPFC_guiVbusMax_Volts = 440;
    TTPLPFC_ac_volRmsEma_sensed_Volts = 0;
    TTPLPFC_guiVin_Volts = 0;


    /*A.D.T Variables: Dead band RED and FED set*/
    TTPLPFC_dbFED_SetValue_ticks = TTPLPFC_HIGH_FREQ_PWM_DEADBAND_FED_COUNT;
    TTPLPFC_dbRED_SetValue_ticks = TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_COUNT;
    TTPLPFC_dbRED_SetValue_Temp_ticks =
            TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_COUNT;
    TTPLPFC_dbRED_Min_ticks = TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_MIN_COUNT;
    TTPLPFC_dbRED_Max_ticks = TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_MAX_COUNT;


    /*Sample and loop variable initialization*/

    //
    //PU of inductor current sensed value.(-0.5~0.5). Used in control.
    //DC bias voltage (1.65V) in current sensed loop.
    //ADC result when inductor current=0. Use
    //TTPLPFC_calibrateOffset() to calculate.
    //
    TTPLPFC_ac_cur_sensed_pu = 0;
    TTPLPFC_iLVrefMeas_pu = 0;
    TTPLPFC_iLMeasOffset_pu = 0;

    //
    //PU of voltage sensed value.(0-1). Used in control.
    //ADC result when BUS voltage=0. Do not use now.
    //Reference for TTPLPFC_vBusRefSlewed_pu.
    //Result of vBus after use one notch filter.
    //Result of vBus after use two notch filter.
    //
    TTPLPFC_vBus_sensed_pu = 0;
    TTPLPFC_vBusMeasOffset_pu = 0;
    TTPLPFC_vBusRef_pu =
            TTPLPFC_VBUS_TYPICAL_VOLT / TTPLPFC_VDCBUS_MAX_SENSE_VOLT;
    TTPLPFC_vBus_sensedFiltered_notch1 = 0;
    TTPLPFC_vBus_sensedFiltered_notch2 = 0;

    //
    //Voltage loop PI output for current reference
    //(do not contain phase of Vin).
    //
    TTPLPFC_ac_cur_ref_pu = 0.03f;

    /*Input voltage measurement*/

    //
    //PU of Vin L line voltage sensed value.(0~1).
    //ADC result when Vin=0. Do not use now.
    //PU of Vin N line voltage sensed value.(0~1).
    //ADC result when Vin=0. Do not use now.
    // Do not use now.
    //
    TTPLPFC_ac_L_sensed_pu = 0;
    TTPLPFC_vACLMeasOffset_pu = 0;
    TTPLPFC_ac_N_sensed_pu = 0;
    TTPLPFC_vACNMeasOffset_pu = 0;
    TTPLPFC_vACMeasOffset_pu = 0;

    TTPLPFC_dutyPU = 0;               //PU of duty for ePWM module.
    TTPLPFC_dutyPU_DC = 0;            //PU of duty for TTPLPFC_DC_CHECK=1.
    TTPLPFC_dutyPU_DC = 0.5f;

    TTPLPFC_thetaOffset_pu = 0;          //Current loop reference adjust.
    /*Flags in ISR and idle loop tasks*/
    TTPLPFC_closeGiLoop = 0;          //Flag for close current control loop.
    TTPLPFC_closeGvLoop = 0;          //Flag for voltage current control loop.

    //
    //Flag for control relay.
    //First time enter voltage loop flag.
    //TTPLPFC_acSine=TTPLPFC_spll_sine=TTPLPFC_spll1.sine.
    //Record last period phase of Vin.
    //Start steps in B2 tasks.
    //Flag for change PI for voltage loop.
    //
    TTPLPFC_relayConnect = 0;
    TTPLPFC_firstTimeGvLoop = 1;
    TTPLPFC_acSine = 0;
    TTPLPFC_acSine_Prev = 0;
    TTPLPFC_autoStartSlew = 0;
    TTPLPFC_nonLinearVoltageLoopFlag = 0;

    /*Acsine threshold to switch pwmSwState*/
    TTPLPFC_threshold_PZC1 = PWM_SWITCHING_PZC1;
    TTPLPFC_threshold_PZC2 = PWM_SWITCHING_PZC2;
    TTPLPFC_threshold_NZC1 = PWM_SWITCHING_NZC1;
    TTPLPFC_threshold_NZC2 = PWM_SWITCHING_NZC2;

    /*Results after use digital LPF for vRms and vBus. Use in control loop*/
    TTPLPFC_vACRmsMeasAvg_pu = 0;
    TTPLPFC_vBusAvg_pu = 0;

    TTPLPFC_fsiTxInt1Received = 0;
    TTPLPFC_fsiTxInt2Received = 0;
    TTPLPFC_fsiRxInt1Received = 0;
    TTPLPFC_fsiRxInt2Received = 0;

    TTPLPFC_txEventSts = 0;
    TTPLPFC_rxEventSts = 0;

    TTPLPFC_Handshake_Complete_Flag = 0;

    /*pwmSwState*/
    TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;
    TTPLPFC_stateSlewMax = 10;
    /*LLC shut down flag*/
    TTPLPFC_llcShutdownFlag = 0;
    /*LLC startup flag*/
    TTPLPFC_llcStartupFlag = 0;
    /*Relay control*/
    TTPLPFC_relay_count = 0;
    /*Calibrate measurement offsets*/
    TTPLPFC_k1 = 0.998f;
    TTPLPFC_k2 = 0.001999f;
    TTPLPFC_phase2ScaleFactor = 1.0f;
    /*CLA changable PI flag*/
    TTPLPFC_highPowerTrans_flag = 0;
    /*Graph debug*/
#if TTPLPFC_DEBUG_CHIP == F28004X
    TTPLPFC_graphArrayWatchValueindex1 = 0;
    TTPLPFC_faultTriggerFlag1 = 0;
    TTPLPFC_graphArrayWatchValueindex2 = 0;
    TTPLPFC_faultTriggerFlag1 = 0;
#endif
}


void computeNotchFltrCoeff(DCL_DF22 *coeff, float32_t Fs, float32_t notch_freq,
                           float32_t c1, float32_t c2)
{
    float32_t temp1;
    float32_t temp2;
    float32_t wn2;
    float32_t Ts;
    Ts = 1 / Fs;

    //
    // pre warp the notch frequency
    //
    wn2 = 2 * Fs * tanf(notch_freq * PI_VALUE * Ts);

    temp1 = 4 * Fs * Fs + 4 * wn2 * c2 * Fs + wn2 * wn2;
    temp2 = 1 / ( 4 * Fs * Fs + 4 * wn2 * c1 * Fs + wn2 * wn2);

    coeff->b0 = temp1 * temp2;
    coeff->b1 = (-8 * Fs * Fs + 2 * wn2 * wn2) * temp2;
    coeff->b2 = (4 * Fs * Fs - 4 * wn2 * c2 * Fs + wn2 * wn2) * temp2;
    coeff->a1 = (-8 * Fs * Fs + 2 * wn2 * wn2) * temp2;
    coeff->a2 = (4 * Fs * Fs - 4 * wn2 * c1 * Fs + wn2 * wn2) * temp2;

}


void TTPLPFC_updateBoardStatus()
{
    if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
    {
        if((TTPLPFC_PWM_TRIP_STATUS(EPWM1_BASE) & EPWM_TZ_INTERRUPT_CBC) != 0 )
            TTPLPFC_board_Status.enum_boardStatus =
                    boardStatus_EmulatorStopTrip;
    }

}

void TTPLPFC_runSFRABackGroundTasks(void)
{

    SFRA_F32_runBackgroundTask(&TTPLPFC_sfra1);
    SFRA_GUI_runSerialHostComms(&TTPLPFC_sfra1);

}


void TTPLPFC_setLabIndicatorVariable()
{
#if TTPLPFC_LAB == 1
    #if TTPLPFC_DC_CHECK == 1
        #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
    TTPLPFC_lab.enum_lab = Lab1_CLA;
        #else
    TTPLPFC_lab.enum_lab = Lab1;
        #endif
    #else
        #warning undefined lab
    #endif
#elif TTPLPFC_LAB == 2
    #if TTPLPFC_DC_CHECK == 1
        #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
    TTPLPFC_lab.enum_lab = Lab2_CLA;
        #else
    TTPLPFC_lab.enum_lab = Lab2;
        #endif
    #else
        #warning undefined lab
    #endif
#elif TTPLPFC_LAB == 3
    #if TTPLPFC_DC_CHECK == 0
        #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
    TTPLPFC_lab.enum_lab = Lab3_CLA;
        #else
    TTPLPFC_lab.enum_lab = Lab3;
        #endif
    #else
        #warning undefined lab
    #endif
#elif TTPLPFC_LAB == 4
    #if TTPLPFC_DC_CHECK == 0
        #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
    TTPLPFC_lab.enum_lab = Lab4_CLA;
        #else
    TTPLPFC_lab.enum_lab = Lab4;
        #endif
    #else
        #warning undefined lab
    #endif
#endif

}

// Returns 1 if handshake complete
uint16_t TTPLPFC_HAL_Handshake_Lead(void)
{
    //  Check if ping frame received
    if (FSI_getRxEventStatus(FSIRXA_BASE) & FSI_RX_EVT_PING_FRAME)
    {
        // Check if ping Tag equals TAG0
        if (FSI_getRxPingTag(FSIRXA_BASE) == FSI_FRAME_TAG0)
        {
            return 1; // 1 = ping frame, TAG0 was received
        }
    }

    // If no ping frame, TAG0 received

    //
    // Send the flush sequence
    //
    TTPLPFC_HAL_FsiSendFlushSequence();

    //
    // Send a ping frame with frame tag 0000b
    //
    FSI_setTxFrameTag(FSITXA_BASE, FSI_FRAME_TAG0);
    FSI_setTxFrameType(FSITXA_BASE, FSI_FRAME_TYPE_PING);
    FSI_startTxTransmit(FSITXA_BASE);

    return 0;
}

void TTPLPFC_startLLC()
{
    if (TTPLPFC_Handshake_Complete_Flag == 0)
    {
        TTPLPFC_Handshake_Complete_Flag = TTPLPFC_HAL_Handshake_Lead();
    }

    // send FSI signal to start up LLC
    if(TTPLPFC_guiVbus_Volts < TTPLPFC_guiVbusMax_Volts
            && TTPLPFC_guiVbus_Volts > (TTPLPFC_VBUS_TYPICAL_VOLT-5) && TTPLPFC_llcStartupFlag != 2
            && TTPLPFC_Handshake_Complete_Flag == 1)
    {
        TTPLPFC_HAL_startLLC();//this is start up flag
        TTPLPFC_llcStartupFlag = TTPLPFC_llcStartupFlag + 1; //This allows only 2 startup signals
    }
}

void TTPLPFC_autoStart()
{
#if TTPLPFC_DC_CHECK == 1
    if(TTPLPFC_autoStartSlew < 100)
        TTPLPFC_autoStartSlew++;
#else
    if(TTPLPFC_guiVrms_Volts >= 75.0f)
    {
        if(TTPLPFC_autoStartSlew < 5)
        {
            TTPLPFC_autoStartSlew++;
        }

        if(TTPLPFC_autoStartSlew == 1)
        {
            TTPLPFC_board_Status.enum_boardStatus = boardStatus_Idle;
            TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;
        }

        if(TTPLPFC_autoStartSlew == 2)
        {


            DINT;

            if(TTPLPFC_sine_mains.acFreq > 55)
            {
                TTPLPFC_sine_mains.acFreq = 60;
            }
            else
            {
                TTPLPFC_sine_mains.acFreq = 50;
            }

            SPLL_1PH_SOGI_config(&TTPLPFC_spll1,
                                 TTPLPFC_sine_mains.acFreq,
                                 TTPLPFC_CONTROL_ISR_FREQUENCY,
                                 (float32_t)(222.2862),
                                 (float32_t)(-222.034));

            SPLL_1PH_NOTCH_config(&TTPLPFC_spll2,
                                  TTPLPFC_sine_mains.acFreq,
                                  TTPLPFC_CONTROL_ISR_FREQUENCY,
                                  (float32_t)(222.2862),
                                  (float32_t)(-222.034),
                                  (float32_t) 0.25,
                                  (float32_t) 0.00001);

            SPLL_1PH_SOGI_FLL_config(&TTPLPFC_spll3,
                                     TTPLPFC_sine_mains.acFreq,
                                     TTPLPFC_CONTROL_ISR_FREQUENCY,
                                     (float32_t)(222.2862),
                                     (float32_t)(-222.034),
                                     (float32_t) 0.5,
                                     (float32_t) 20000);

            computeNotchFltrCoeff(&TTPLPFC_notch1,
                             (float32_t)(TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY),
                                   (float32_t)(TTPLPFC_sine_mains.acFreq*2.0f) ,
                                   0.25f,
                                   0.00001f);

            computeNotchFltrCoeff(&TTPLPFC_notch2,
                            (float32_t)(TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY) ,
                                   (float32_t)(TTPLPFC_sine_mains.acFreq*2.0f) ,
                                   0.25f,
                                   0.00001f);

            TTPLPFC_dutyPU = 0.01f;

            TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(TTPLPFC_LOW_FREQ_PWM_BASE);


            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);

            EINT;

            TTPLPFC_nonLinearVoltageLoopFlag = 0;

        }

        if(TTPLPFC_autoStartSlew == 3)
        {
            if(TTPLPFC_guiVrms_Volts < 150 )
            {
                TTPLPFC_thetaOffset_pu
                = TTPLPFC_LOW_LINE_INPUT_CAP_COMP_ADJUST;
            }
            else
            {
                TTPLPFC_thetaOffset_pu
                = TTPLPFC_HIGH_LINE_INPUT_CAP_COMP_ADJUST;
            }

            DINT;
            TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_LOW_FREQ_PWM_BASE);
            TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_HIGH_FREQ_PWM_BASE);
            TTPLPFC_board_Status.enum_boardStatus = boardStatus_NoFault;
            EINT;

        }




    }
    else
    {
        TTPLPFC_relayConnect = 0;
        TTPLPFC_autoStartSlew = 0;
        TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;
        TTPLPFC_closeGiLoop = 0;
        TTPLPFC_closeGvLoop = 0;

    }
#endif

#if TTPLPFC_DC_CHECK == 1
    if(TTPLPFC_autoStartSlew == 100)
#else
    if(TTPLPFC_autoStartSlew == 4)
#endif
    {

        DINT;

        TTPLPFC_vBusRefSlewed_pu = 0;

        TTPLPFC_gv.i6 = 0;
        TTPLPFC_gv.i10 = 0;

        TTPLPFC_gi.i10 = 0;
        TTPLPFC_gi.i6 = 0;

        TTPLPFC_closeGiLoop = 0;
        TTPLPFC_closeGvLoop = 0;

        TTPLPFC_firstTimeGvLoop = 1;

        TTPLPFC_stateSlew = 0;
        TTPLPFC_softStartDuty_ticks = 0;

        TTPLPFC_vBusRef_pu =
                TTPLPFC_VBUS_TYPICAL_VOLT / TTPLPFC_VDCBUS_MAX_SENSE_VOLT;

        TTPLPFC_ac_cur_ref_pu = 0.03f;

        TTPLPFC_ac_cur_ref_inst_pu = 0 ;
        TTPLPFC_ac_cur_ref_inst_prev_pu = 0;

        TTPLPFC_acSine = 0;
        TTPLPFC_acSine_Prev = 0;

        TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_normalOperation;

        EINT;

        TTPLPFC_autoStartSlew++;

#if TTPLPFC_DC_CHECK == 1

        TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_LOW_FREQ_PWM_BASE);
        TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_HIGH_FREQ_PWM_BASE);

        TTPLPFC_relayConnect = 1;
        TTPLPFC_closeGiLoop = 1;

#endif

    }
}


void TTPLPFC_relayControl()
{
    if(TTPLPFC_relay_count < 4)
    {
        TTPLPFC_relay_count++;
    }

if(TTPLPFC_relay_count == 4)
{
#if TTPLPFC_DC_CHECK == 0
    if(TTPLPFC_guiVrms_Volts > 75.0f || TTPLPFC_guiVbus_Volts > 110.0f)
    {
        TTPLPFC_relayConnect = 1;
    }
    else
    {
        TTPLPFC_relayConnect = 0;
    }
#endif

#if TTPLPFC_DC_CHECK == 0
    if(fabsf(TTPLPFC_acSine) < 0.05f)
    {
        if(TTPLPFC_relayConnect == 1)
        {
            TTPLPFC_HAL_closeRelay();
        }
    }

    if(TTPLPFC_relayConnect == 0)
    {
        TTPLPFC_HAL_openRelay();
    }
#else
    if(TTPLPFC_relayConnect == 1)
    {
        TTPLPFC_HAL_closeRelay();
    }
    else
    {
        TTPLPFC_HAL_openRelay();
    }
#endif
}
}

void TTPLPFC_llcStatusFlag()
{
    if(TTPLPFC_fsiRxInt1Received == 1)
    {
        TTPLPFC_fsiRxInt1Received = 0;
    }
}

void TTPLPFC_monitorVariable()
{
    TTPLPFC_IsrTicker++;
    if(TTPLPFC_usShowCnt > 100) TTPLPFC_usShowCnt = 0;
    TTPLPFC_Watchvalue[TTPLPFC_usShowCnt]
                        = *TTPLPFC_iqGraphIdTab1[TTPLPFC_uGraphID];
    TTPLPFC_Watchvalue1[TTPLPFC_usShowCnt]
                        = *TTPLPFC_iqGraphIdTab1[TTPLPFC_uGraphID2];

    if(TTPLPFC_IsrTicker % TTPLPFC_usShowDiv == 0) TTPLPFC_usShowCnt++;
    if(TTPLPFC_IsrTicker > 10000)  TTPLPFC_IsrTicker = 0;

}


void TTPLPFC_calibrateOffset(volatile float32_t *ac_cur_sensedOffset,
                             float32_t k1, float32_t k2)
{
    int16_t offsetCalCounter = 0;

    TTPLPFC_HAL_enablePWMInterruptGeneration(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);

    offsetCalCounter = 0;
    while(offsetCalCounter < 20000)
    {
        if(EPWM_getEventTriggerInterruptStatus(
                TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE) == 1)
        {
            if(offsetCalCounter > 1000)
            {
                //
                //Offset of the inductor current sense
                //
                *ac_cur_sensedOffset =  k1 * (*ac_cur_sensedOffset) +
                                        k2 * (TTPLPFC_IL_FB_1)
                                        * TTPLPFC_ADC_PU_SCALE_FACTOR;

            }
            EPWM_clearEventTriggerInterruptFlag(
                    TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);
            offsetCalCounter++;
        }
    }

    ADC_setPPBCalibrationOffset(ADCA_BASE, ADC_PPB_NUMBER1, (0*4096.0f));
    ADC_setPPBCalibrationOffset(ADCA_BASE, ADC_PPB_NUMBER2, (0*4096.0f));
    ADC_setPPBCalibrationOffset(ADCA_BASE, ADC_PPB_NUMBER3, (0*4096.0f));
}


#if TTPLPFC_SFRA_TYPE != TTPLPFC_SFRA_DISABLED

void TTPLPFC_setupSFRA(void)
{
    SFRA_F32_reset(&TTPLPFC_sfra1);
    SFRA_F32_config(&TTPLPFC_sfra1,
                    TTPLPFC_SFRA_ISR_FREQ,
                    TTPLPFC_SFRA_AMPLITUDE,
                    TTPLPFC_SFRA_FREQ_LENGTH,
                    TTPLPFC_SFRA_FREQ_START,
                    TTPLPFC_SFRA_FREQ_STEP_MULTIPLY,
                    TTPLPFC_plantMagVect,
                    TTPLPFC_plantPhaseVect,
                    TTPLPFC_olMagVect,
                    TTPLPFC_olPhaseVect,
                    NULL,
                    NULL,
                    TTPLPFC_freqVect,
                    1);

    SFRA_F32_resetFreqRespArray(&TTPLPFC_sfra1);

    //
    // Re-initialize the frequency array to make SFRA sweep go fast
    //
    i = 0;

    #if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_CURRENT// current loop
        TTPLPFC_sfra1.freqVect[i++] = TTPLPFC_SFRA_FREQ_START;
        for(;i < TTPLPFC_sfra1.vecLength;i++)
        {
            if(TTPLPFC_sfra1.freqVect[i - 1] < 10)
                TTPLPFC_sfra1.freqVect[i] = TTPLPFC_sfra1.freqVect[i - 1] + 2;
            else if(TTPLPFC_sfra1.freqVect[i - 1] < 50)
                TTPLPFC_sfra1.freqVect[i] = TTPLPFC_sfra1.freqVect[i - 1] + 10;
            else
                TTPLPFC_sfra1.freqVect[i] = TTPLPFC_sfra1.freqVect[i - 1]
                                                    * TTPLPFC_sfra1.freqStep;
        }
    #else
        TTPLPFC_sfra1.freqVect[0] = 2;
        TTPLPFC_sfra1.freqVect[1] = 4;
        TTPLPFC_sfra1.freqVect[2] = 6;
        TTPLPFC_sfra1.freqVect[3] = 8;
        TTPLPFC_sfra1.freqVect[4] = 10;
        TTPLPFC_sfra1.freqVect[5] = 12;
        TTPLPFC_sfra1.freqVect[6] = 14;
        TTPLPFC_sfra1.freqVect[7] = 16;
        TTPLPFC_sfra1.freqVect[8] = 18;
        TTPLPFC_sfra1.freqVect[9] = 20;
        TTPLPFC_sfra1.freqVect[10] = 22;
        TTPLPFC_sfra1.freqVect[11] = 24;
        TTPLPFC_sfra1.freqVect[12] = 26;
        TTPLPFC_sfra1.freqVect[13] = 28;
        TTPLPFC_sfra1.freqVect[14] = 30;
        TTPLPFC_sfra1.freqVect[15] = 35;
        TTPLPFC_sfra1.freqVect[16] = 40;
        TTPLPFC_sfra1.freqVect[17] = 45;
        TTPLPFC_sfra1.freqVect[18] = 55;
        TTPLPFC_sfra1.freqVect[19] = 65;
        TTPLPFC_sfra1.freqVect[20] = 70;
        TTPLPFC_sfra1.freqVect[21] = 80;
        TTPLPFC_sfra1.freqVect[22] = 90;
        TTPLPFC_sfra1.freqVect[23] = 130;
        TTPLPFC_sfra1.freqVect[24] = 140;
        TTPLPFC_sfra1.freqVect[25] = 150;
        TTPLPFC_sfra1.freqVect[26] = 160;
        TTPLPFC_sfra1.freqVect[27] = 170;
        TTPLPFC_sfra1.freqVect[28] = 210;
        TTPLPFC_sfra1.freqVect[29] = 250;
    #endif

    SFRA_GUI_config(TTPLPFC_SFRA_GUI_SCI_BASE,
                    TTPLPFC_SCI_VBUS_CLK,
                    TTPLPFC_SFRA_GUI_SCI_BAUDRATE,
                    TTPLPFC_SFRA_GUI_SCIRX_GPIO,
                    TTPLPFC_SFRA_GUI_SCIRX_GPIO_PIN_CONFIG,
                    TTPLPFC_SFRA_GUI_SCITX_GPIO,
                    TTPLPFC_SFRA_GUI_SCITX_GPIO_PIN_CONFIG,
                    TTPLPFC_SFRA_GUI_LED_INDICATOR,
                    TTPLPFC_SFRA_GUI_LED_GPIO,
                    TTPLPFC_SFRA_GUI_LED_GPIO_PIN_CONFIG,
                    &TTPLPFC_sfra1,
                    1);

}

#endif

