//#############################################################################
//
// FILE:   ttplpfc.h
//
// TITLE: This is the solution header file.
//
//#############################################################################
// $TI Release: TIDA_010062 v2.02.00.00 $
// $Release Date: Fri Oct  6 19:11:54 CDT 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#ifndef TTPLPFC_H
#define TTPLPFC_H

#ifdef __cplusplus

extern "C" {
#endif

//
// the includes
//
#include <stdint.h>
#include <stddef.h>

#ifndef __TMS320C28XX_CLA__
#include <math.h>
#else
#include <CLAmath.h>
#endif

//
// this is the file generated by the powerSUITE page for this system
//
#include <ttplpfc_settings.h>
#include <ttplpfc_hal.h>

//
// Library header files
// DCL Library is used for the controller implementation
// GI -> series form of DCL_PI for current loop (TTPLPFC_gi),
// GV -> parallel form of DCL_PI for voltage loop (TTPLPFC_gv),
// NOTCH_2P2Z -> notch filter using DCL_DF22 which implements a 2p2z structure
//
#ifndef __TMS320C28XX_CLA__
#include "DCLF32.h"
#define TTPLPFC_GI DCL_PI

//
// GI on C28x ,run DCL_PI routine written in assembly
//
#define GI_RUN DCL_runPI_C1
#define TTPLPFC_GV DCL_PI

//
// TTPLPFC_gv on C28x, run DCL_PI routine written in assembly
//
#define GV_RUN DCL_runPI_C4
#define TTPLPFC_NOTCH_2P2Z DCL_DF22

//
// notch filter on C28x, run DCL_DF22 routine written in assembly
//
#define NOTCH_2P2Z_RUN DCL_runDF22_C1
#else
#include "DCLCLA.h"

//
//GI
//
#define TTPLPFC_GI DCL_PI_CLA

//
// GI on CLA, run DCL_PI routine written in CLA assembly
//
#define GI_RUN DCL_runPI_L1

#define TTPLPFC_GV DCL_PI_CLA

//
// TTPLPFC_gv on CLA, run DCL_PI routine written as inline function
// because it is called in the background task
//
#define GV_RUN DCL_runPI_L4

#define TTPLPFC_NOTCH_2P2Z DCL_DF22_CLA

//
// notch filter on CLA, run DCL_DF22 routine written as inline function
// because it is called in the background task
//
#define NOTCH_2P2Z_RUN DCL_runDF22_L4

#pragma FUNC_ALWAYS_INLINE(DCL_runDF22_L4)
#pragma FUNC_ALWAYS_INLINE(CLAsqrt_inline)

#define PR_CNTL_STRUCT DCL_DF22_CLA

#endif

#include "dlog_4ch.h"
#include "rampgen.h"
#include "spll_1ph_sogi.h"
#include "spll_1ph_notch.h"
#include "spll_1ph_sogi_fll.h"
#include "power_meas_sine_analyzer.h"
#pragma FUNC_ALWAYS_INLINE(POWER_MEAS_SINE_ANALYZER_run)
#pragma FUNC_ALWAYS_INLINE(EPWM_setActionQualifierContSWForceAction)

#define TTPLPFC_RAMP RAMPGEN

#ifndef __TMS320C28XX_CLA__
#include "sfra_f32.h"
#include "sfra_gui_scicomms_driverlib.h"
#else
#define SFRA_F32_inject(m)    m
#define SFRA_F32_collect(m, n)
#endif

//
// defines
//

#define PWM_SWITCHING_NZC1 (float32_t)0.01
#define PWM_SWITCHING_NZC2 (float32_t)-0.01
#define PWM_SWITCHING_PZC1 (float32_t)-0.01
#define PWM_SWITCHING_PZC2 (float32_t)0.01

#define EMAVG_MACRO(in, out, multiplier) out = ((in - out) * multiplier) + out;

//
// System Settings
//
//Add any system specific setting below
//SFRA related defines.
//
#if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_VOLTAGE // voltage loop
    #define TTPLPFC_SFRA_FREQ_START             2
    #define TTPLPFC_SFRA_FREQ_LENGTH            30

    //
    //SFRA step Multiply = 10^(1/No of steps per decade(40))
    //
    #define TTPLPFC_SFRA_FREQ_STEP_MULTIPLY     (float32_t)1.08
    #define TTPLPFC_SFRA_AMPLITUDE              (float32_t)0.005
#elif TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_CURRENT // current loop
    #if TTPLPFC_DC_CHECK == 1
        #define TTPLPFC_SFRA_FREQ_START 30

        //
        //SFRA step Multiply = 10^(1/No of steps per decade(40))
        //
        #define TTPLPFC_SFRA_FREQ_STEP_MULTIPLY (float32_t)1.07
        #define TTPLPFC_SFRA_AMPLITUDE (float32_t)0.005
    #else
        #define TTPLPFC_SFRA_FREQ_START 200

        //
        //SFRA step Multiply = 10^(1/No of steps per decade(40))
        //
        #define TTPLPFC_SFRA_FREQ_STEP_MULTIPLY (float32_t)1.052
        #define TTPLPFC_SFRA_AMPLITUDE (float32_t)0.01
#endif
        #define TTPLPFC_SFRA_FREQ_LENGTH 100
#endif

#define GRID_MAX_FREQ 70
#define GRID_MIN_FREQ 40

//
// typedefs
//

typedef union{
    enum
    {
        Lab1 = 0,
        Lab2 = 1,
        Lab3 = 2,
        Lab4 = 3,
        Lab1_CLA = 4,
        Lab2_CLA = 5,
        Lab3_CLA = 6,
        Lab4_CLA = 7,
    }enum_lab ;
    int32_t pad;
}TTPLPFC_Lab_EnumType;//TTPLPFC_Lab_EnumType

extern TTPLPFC_Lab_EnumType TTPLPFC_lab;

typedef union{
    enum
    {
        boardState_OFF = 0,
        boardState_CheckACInput = 1,
        boardState_RlyConnect = 2,
        boardState_PowerStageON = 3,
        boardState_TripCondition = 4,
    }enum_boardState;
    int32_t pad;
}TTPLPFC_boardState;

extern TTPLPFC_boardState TTPLPFC_board_State;

typedef union{
    enum
    {
        boardStatus_Idle = 0,
        boardStatus_NoFault = 1,
        boardStatus_OverCurrentTrip = 2,
        boardStatus_EmulatorStopTrip = 3,
        boardStatus_OverVoltageTrip = 4,
        boardStatus_InputUnderVoltageTrip = 5,
    }enum_boardStatus;
    int32_t pad;
}TTPLPFC_boardStatus;

extern TTPLPFC_boardStatus TTPLPFC_board_Status;

typedef union{
    enum
    {
        pwmSwState_normalOperation = 0,
        pwmSwState_positiveHalf = 1,
        pwmSwState_negativeZeroCrossing1 = 2,
        pwmSwState_negativeZeroCrossing2 = 3,
        pwmSwState_negativeZeroCrossing3 = 4,
        pwmSwState_negativeHalf = 5,
        pwmSwState_positiveZeroCrossing1 = 6,
        pwmSwState_positiveZeroCrossing2 = 7,
        pwmSwState_positiveZeroCrossing3 = 8,
        pwmSwState_defaultState = 9,
    }enum_pwmSwState;
    int32_t pad;
}TTPLPFC_pwmSwState;

extern TTPLPFC_pwmSwState TTPLPFC_pwm_SwState;





//
// globals
//

//
// RAMP to generate forced angle when grid is not present
//
extern TTPLPFC_RAMP TTPLPFC_rgen;

//
//PI regulator
//
extern volatile TTPLPFC_GI TTPLPFC_gi;
extern volatile TTPLPFC_GV TTPLPFC_gv;

//
//SPLL
//
extern SPLL_1PH_SOGI TTPLPFC_spll1;
extern SPLL_1PH_NOTCH TTPLPFC_spll2;
extern SPLL_1PH_SOGI_FLL TTPLPFC_spll3;
extern TTPLPFC_NOTCH_2P2Z TTPLPFC_notch1, TTPLPFC_notch2;

//
// Sine analyzer block for RMS Volt, Curr and Power measurements
//
extern volatile POWER_MEAS_SINE_ANALYZER TTPLPFC_sine_mains;

#ifndef __TMS320C28XX_CLA__

//
// datalogger
//
extern DLOG_4CH TTPLPFC_dLog1;
extern float32_t TTPLPFC_dBuff1[100], TTPLPFC_dBuff2[100],
                 TTPLPFC_dBuff3[100], TTPLPFC_dBuff4[100];
extern float32_t TTPLPFC_dVal1, TTPLPFC_dVal2, TTPLPFC_dVal3, TTPLPFC_dVal4;

//
//--- SFRA Related Variables ---
//
    #if TTPLPFC_SFRA_TYPE != TTPLPFC_SFRA_DISABLED
    extern float32_t TTPLPFC_plantMagVect[TTPLPFC_SFRA_FREQ_LENGTH];
    extern float32_t TTPLPFC_plantPhaseVect[TTPLPFC_SFRA_FREQ_LENGTH];
    extern float32_t TTPLPFC_olMagVect[TTPLPFC_SFRA_FREQ_LENGTH];
    extern float32_t TTPLPFC_olPhaseVect[TTPLPFC_SFRA_FREQ_LENGTH];
    extern float32_t TTPLPFC_freqVect[TTPLPFC_SFRA_FREQ_LENGTH];
    #endif
extern SFRA_F32 TTPLPFC_sfra1;
extern int16_t i;
#endif
extern volatile int16_t TTPLPFC_initializationFlag;

//
// Display Values
//
extern volatile float32_t TTPLPFC_guiVbus_Volts;
extern float32_t TTPLPFC_guiVbusMax_Volts;
extern float32_t TTPLPFC_guiACFreq_Hz;
extern float32_t TTPLPFC_guiPrms_W;
extern float32_t TTPLPFC_guiIrms_Amps;
extern volatile float32_t TTPLPFC_guiVrms_Volts;
extern float32_t TTPLPFC_guiVavg_Volts;
extern float32_t TTPLPFC_guiFreqAvg_Hz;
extern float32_t TTPLPFC_guiVema_Volts;
extern float32_t TTPLPFC_ac_volRmsEma_sensed_Volts;
extern float32_t TTPLPFC_guiVin_Volts;

//
//DBRED&DBFED
//
extern uint32_t TTPLPFC_dbRED_SetValue_ticks;
extern uint32_t TTPLPFC_dbRED_SetValue_Temp_ticks;
extern volatile uint32_t TTPLPFC_dbFED_SetValue_ticks;
extern uint32_t TTPLPFC_dbRED_Min_ticks;
extern uint32_t TTPLPFC_dbRED_Max_ticks;

//
// Control Variables
// AC Current Measurement
//
extern volatile float32_t TTPLPFC_ac_cur_sensed_pu, TTPLPFC_iLVrefMeas_pu;
extern volatile float32_t TTPLPFC_ac_cur_ref_pu;
extern float32_t TTPLPFC_iLMeasScaled_Amps;
extern float32_t TTPLPFC_iLMeasOffset_pu;
extern float32_t TTPLPFC_ac_cur_ref_inst_pu, TTPLPFC_ac_cur_ref_inst_prev_pu;

//
// Output Voltage measurement
//
extern volatile float32_t TTPLPFC_vBus_sensed_pu;
extern float32_t TTPLPFC_vBusMeasOffset_pu;
extern float32_t TTPLPFC_vBusRef_pu;
extern float32_t TTPLPFC_vBus_sensedFiltered_notch1;
extern float32_t TTPLPFC_vBus_sensedFiltered_notch2;

//
//Input voltage measurement
//
extern volatile float32_t TTPLPFC_ac_L_sensed_pu,
                          TTPLPFC_ac_N_sensed_pu, TTPLPFC_ac_vol_sensed_pu;
extern float32_t TTPLPFC_vACLMeasOffset_pu,
                 TTPLPFC_vACNMeasOffset_pu, TTPLPFC_vACMeasOffset_pu;

//
// per unit duty value
//
extern volatile float32_t TTPLPFC_dutyPU, TTPLPFC_dutyPU_DC;
extern volatile float32_t TTPLPFC_thetaOffset_pu;

//
// Flags for clearing trips and closing the loops and the Relay
//
extern volatile int32_t TTPLPFC_relayConnect;
extern int32_t TTPLPFC_closeGiLoop, TTPLPFC_closeGvLoop;
extern int32_t TTPLPFC_autoStartSlew, TTPLPFC_firstTimeGvLoop;

// FSI ISR status flag
extern volatile uint32_t TTPLPFC_fsiTxInt1Received, TTPLPFC_fsiTxInt2Received;
extern volatile uint32_t TTPLPFC_fsiRxInt1Received, TTPLPFC_fsiRxInt2Received;

//
// Globals, these are not config parameters, user are not required to edit them
//
extern uint16_t TTPLPFC_txEventSts, TTPLPFC_rxEventSts;

//
// Flags for detecting ZCD
//
extern volatile float32_t TTPLPFC_acSine;
extern float32_t TTPLPFC_acSine_Prev;
extern float32_t TTPLPFC_threshold_PZC1, TTPLPFC_threshold_PZC2;
extern float32_t TTPLPFC_threshold_NZC1, TTPLPFC_threshold_NZC2;

//
// 1 if using non linear voltage loop, 0 otherwise
//
extern uint32_t TTPLPFC_nonLinearVoltageLoopFlag;

//
// Filtered DC bus measurement
//
extern float32_t TTPLPFC_vBusAvg_pu;
extern float32_t TTPLPFC_vACRmsMeasAvg_pu;

extern float32_t TTPLPFC_inductor_voltage_drop_feedforward;

//
//voltage set point
//
extern float32_t  TTPLPFC_vBusRefSlewed_pu;

//
//Other display Values
//
extern float32_t TTPLPFC_guiIL_Amps;
extern float32_t TTPLPFC_guiPowerFactor;
extern float32_t TTPLPFC_guiVA_VA;

//
//Soft start in pwmSwState switch
//
extern float32_t TTPLPFC_softStartDuty_ticks;
extern int32_t TTPLPFC_stateSlew;
extern int32_t TTPLPFC_stateSlewMax;
extern volatile uint32_t TTPLPFC_softStartDeadBandFED_ticks;

//
//Controller output.
//
extern volatile float32_t TTPLPFC_gi_out;
extern float32_t TTPLPFC_gv_out, TTPLPFC_gi_pi_ki;

//
//Filter BUS voltage sensed result.
//Status flags.
//
extern volatile float32_t TTPLPFC_vBusMeasBuff_pu[10];
extern float32_t TTPLPFC_vBusMeasFiltered_pu;
extern int32_t TTPLPFC_vBusMeasBuffIndex;

//
//SPLL result. Vin direction.
//
extern float32_t TTPLPFC_spll_sine, TTPLPFC_spll_cosine;
extern int32_t TTPLPFC_ac_sign_filtered;

//
//Voltage loop flag.
//
extern float32_t TTPLPFC_vBusError_pu;

extern float32_t TTPLPFC_phase2ScaleFactor;

//
//LLC shutdown.
//
extern int16_t TTPLPFC_llcShutdownFlag;

//
//Relay control.
//
extern uint16_t TTPLPFC_relay_count;

//
// Variables used to calibrate measurement offsets
//
extern float32_t TTPLPFC_k1;
extern float32_t TTPLPFC_k2;
extern volatile int16_t TTPLPFC_highPowerTrans_flag;

//
//User monitoring variables.
//
extern volatile float32_t *TTPLPFC_iqGraphIdTab1[5];
extern uint16_t TTPLPFC_uGraphID;
extern uint16_t TTPLPFC_uGraphID2;
extern uint16_t TTPLPFC_IsrTicker;
extern uint16_t TTPLPFC_usShowCnt;
extern uint16_t TTPLPFC_usShowDiv;
extern float32_t TTPLPFC_Watchvalue[100];
extern float32_t TTPLPFC_Watchvalue1[100];

#if TTPLPFC_DEBUG_CHIP == F28004X
extern float32_t TTPLPFC_graphArrayWatchValue1[1600];
extern float32_t TTPLPFC_graphArrayWatchValue2[1600];
extern uint16_t TTPLPFC_graphArrayWatchValueindex1;
extern uint16_t TTPLPFC_faultTriggerFlag1;
extern float32_t TTPLPFC_graphArrayWatchValue3[2000];
extern float32_t TTPLPFC_graphArrayWatchValue4[2000];
extern uint16_t TTPLPFC_graphArrayWatchValueindex2;
extern uint16_t TTPLPFC_faultTriggerFlag2;//0 No fault 1 Fault
#endif

//
// the function prototypes
//

void TTPLPFC_runSFRABackGroundTasks(void);

#ifndef __TMS320C28XX_CLA__
void TTPLPFC_setupSFRA();
void TTPLPFC_globalVariablesInit();
#else
#endif

void computeNotchFltrCoeff(TTPLPFC_NOTCH_2P2Z *coeff,
                           float32_t Fs, float32_t notch_freq,
                           float32_t c1, float32_t c2);
void TTPLPFC_updateBoardStatus(void);
void TTPLPFC_setLabIndicatorVariable(void);
void TTPLPFC_autoStart(void);
void TTPLPFC_startLLC(void);
uint16_t TTPLPFC_HAL_Handshake_Lead(void);
void TTPLPFC_relayControl(void);
void TTPLPFC_monitorVariable(void);
void TTPLPFC_calibrateOffset(volatile float32_t *ac_cur_sensedOffset,
                             float32_t k1, float32_t k2);
void TTPLPFC_llcStatusFlag(void);


#pragma FUNC_ALWAYS_INLINE(TTPLPFC_read_acReturnCurrent)
static inline void TTPLPFC_read_acReturnCurrent()
{
    TTPLPFC_ac_cur_sensed_pu = (((float32_t)(TTPLPFC_IL_FB_1 +
                            TTPLPFC_IL_FB_2))
                            * 0.5f * TTPLPFC_ADC_PU_SCALE_FACTOR
                            - (TTPLPFC_iLMeasOffset_pu)) * 1.0f;
    TTPLPFC_iLVrefMeas_pu = (((float32_t)(TTPLPFC_IL_VREF_FB_1 +
                            TTPLPFC_IL_VREF_FB_2)
                            * 0.5f * TTPLPFC_ADC_PU_SCALE_FACTOR));
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_read_acVoltage_separateResistor)
static inline void TTPLPFC_read_acVoltage_separateResistor()
{
    TTPLPFC_ac_L_sensed_pu = (((float32_t) (TTPLPFC_VAC_L_FB_1 +
                             TTPLPFC_VAC_L_FB_2)
                             * 0.5f * TTPLPFC_ADC_PU_SCALE_FACTOR));

    TTPLPFC_ac_N_sensed_pu = (((float32_t) (TTPLPFC_VAC_N_FB_1 +
                             TTPLPFC_VAC_N_FB_2)
                             * 0.5f * TTPLPFC_ADC_PU_SCALE_FACTOR));

    TTPLPFC_ac_vol_sensed_pu = TTPLPFC_ac_L_sensed_pu - TTPLPFC_ac_N_sensed_pu;
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_read_busVoltage)
static inline void TTPLPFC_read_busVoltage()
{
    TTPLPFC_vBus_sensed_pu =  (float32_t)(TTPLPFC_VBUS_FB_1 + TTPLPFC_VBUS_FB_2)
                              * 0.5f * TTPLPFC_ADC_PU_SCALE_FACTOR;
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_rampGenerate)
static inline void TTPLPFC_rampGenerate()
{
    //
    //Generate the RAMP Angle, amplitude is [0,1]
    //
    RAMPGEN_run(&TTPLPFC_rgen);

    //
    //Use the angle value to compute the sine value
    //
    TTPLPFC_acSine_Prev = TTPLPFC_acSine;
    TTPLPFC_acSine = sinf(TTPLPFC_rgen.out * ((float32_t)6.283185307));
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runCurrentLoop)
static inline void TTPLPFC_runCurrentLoop()
{
    if(TTPLPFC_closeGiLoop == 1)
    {

    //
    //Discrete PI regulator.
    //
    #if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_CURRENT
        TTPLPFC_gi_out = GI_RUN(&TTPLPFC_gi, TTPLPFC_ac_cur_sensed_pu,
                      SFRA_F32_inject(TTPLPFC_ac_cur_ref_inst_pu));
    #else
        TTPLPFC_gi_out = GI_RUN(&TTPLPFC_gi,
                                TTPLPFC_ac_cur_sensed_pu,
                                TTPLPFC_ac_cur_ref_inst_pu);
    #endif

    //
    //Current loop PI regulator output plus feed forward output.
    //
        TTPLPFC_dutyPU = ( TTPLPFC_gi_out + (TTPLPFC_ac_vol_sensed_pu *
                            (float32_t)TTPLPFC_VAC_MAX_SENSE_VOLT /
                            (float32_t)TTPLPFC_VDCBUS_MAX_SENSE_VOLT)
                            - TTPLPFC_inductor_voltage_drop_feedforward )
                            / (TTPLPFC_vBus_sensed_pu);

    //
    //Saturation.
    //
        TTPLPFC_dutyPU = (TTPLPFC_dutyPU >
        (float32_t)(1.0f))?(float32_t)(1.0f):TTPLPFC_dutyPU;
        TTPLPFC_dutyPU = (TTPLPFC_dutyPU <
        (float32_t)(-1.0f))?(float32_t)(-1.0f):TTPLPFC_dutyPU;
    }
    else
    {
        TTPLPFC_dutyPU = 0.01f;
    }
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_acCurrentRef)
static inline void TTPLPFC_acCurrentRef()
{
    if(TTPLPFC_closeGiLoop == 1)
    {
        #if  TTPLPFC_DC_CHECK == 1
        TTPLPFC_ac_cur_ref_inst_pu = TTPLPFC_ac_cur_ref_pu;
        #else
            #if TTPLPFC_INPUT_CAP_COMPENSATION == 1
                TTPLPFC_ac_cur_ref_inst_pu = TTPLPFC_ac_cur_ref_pu *
                        TTPLPFC_spll_sine
                        + TTPLPFC_thetaOffset_pu * TTPLPFC_spll_cosine;
            #else
                TTPLPFC_ac_cur_ref_inst_pu = TTPLPFC_ac_cur_ref_pu *
                        TTPLPFC_spll1.sine;
            #endif
        #endif
    }

    //
    //Calculate inductor voltage drop feed-forward.
    //
    TTPLPFC_inductor_voltage_drop_feedforward = -(float32_t)1.0 *
                                (TTPLPFC_ac_cur_ref_inst_pu -
                                TTPLPFC_ac_cur_ref_inst_prev_pu) *
                                ((float32_t)TTPLPFC_PFC_INDUCTOR_VALUE *
                                TTPLPFC_CONTROL_ISR_FREQUENCY *
                                TTPLPFC_IL_MAX_SENSE_AMPS /
                                TTPLPFC_VDCBUS_MAX_SENSE_VOLT);

        TTPLPFC_ac_cur_ref_inst_prev_pu = TTPLPFC_ac_cur_ref_inst_pu;
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runVoltageLoop)
static inline void TTPLPFC_runVoltageLoop()
{
    if(TTPLPFC_closeGvLoop == 1)
    {
        if(fabsf(TTPLPFC_vBusRef_pu - TTPLPFC_vBusRefSlewed_pu) > 0.0001f)
        {
            if(TTPLPFC_vBusRef_pu > TTPLPFC_vBusRefSlewed_pu)
            {
                TTPLPFC_vBusRefSlewed_pu = TTPLPFC_vBusRefSlewed_pu + 0.0001f;
            }
            else
            {
                TTPLPFC_vBusRefSlewed_pu = TTPLPFC_vBusRefSlewed_pu - 0.0001f;
            }
        }
        else
        {
            TTPLPFC_vBusRefSlewed_pu = TTPLPFC_vBusRef_pu;
        }

        #if TTPLPFC_NON_LINEAR_VOLTAGE_LOOP == 1
        TTPLPFC_nonLinearVoltageLoopFlag = 1;
        #else
        TTPLPFC_nonLinearVoltageLoopFlag = 0;
        #endif

    }

    if(TTPLPFC_closeGvLoop == 1)
    {
        if(TTPLPFC_firstTimeGvLoop == 1)
        {
            TTPLPFC_vBusRefSlewed_pu = TTPLPFC_vBus_sensed_pu;
            TTPLPFC_firstTimeGvLoop = 0;
        }

        TTPLPFC_vBusError_pu = fabsf(TTPLPFC_vBusRefSlewed_pu
                                     - TTPLPFC_vBus_sensedFiltered_notch2);

        if(TTPLPFC_nonLinearVoltageLoopFlag == 0)
        {
            TTPLPFC_gv.Kp = TTPLPFC_GV_PI_KP;
            TTPLPFC_gv.Ki = TTPLPFC_GV_PI_KI;
        }
        else
        {
            if(TTPLPFC_vBusError_pu > 0.005f)
            {
                if(TTPLPFC_gv.Kp < (
                        TTPLPFC_NON_LINEAR_V_LOOP_KP_MULTIPLIER
                        * TTPLPFC_GV_PI_KP))
                {
                    TTPLPFC_gv.Kp = TTPLPFC_gv.Kp + 0.05f;
                }
            }
            else if(TTPLPFC_vBusError_pu < 0.001f)
            {
                if(TTPLPFC_gv.Kp > TTPLPFC_GV_PI_KP)
                {
                    TTPLPFC_gv.Kp = TTPLPFC_gv.Kp - 0.05f;
                }
            }
        }


        #if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_VOLTAGE
            TTPLPFC_gv_out = GV_RUN(&TTPLPFC_gv,
                                  SFRA_F32_inject(TTPLPFC_vBusRefSlewed_pu),
                                  TTPLPFC_vBus_sensedFiltered_notch2);
        #else
            TTPLPFC_gv_out = GV_RUN(&TTPLPFC_gv,
                                    TTPLPFC_vBusRefSlewed_pu,
                                    TTPLPFC_vBus_sensedFiltered_notch2);
        #endif

        #if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_VOLTAGE
            SFRA_F32_collect((float32_t*)&TTPLPFC_gv_out,
                             (float32_t*)&TTPLPFC_vBus_sensedFiltered_notch2);
        #endif

            TTPLPFC_ac_cur_ref_pu = TTPLPFC_gv_out *
                    TTPLPFC_vBusAvg_pu / (TTPLPFC_vACRmsMeasAvg_pu);
    }
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_pwmDriver)
static inline void TTPLPFC_pwmDriver()
{
#if TTPLPFC_DC_CHECK == 0
    switch(TTPLPFC_pwm_SwState.enum_pwmSwState)
    {
        /*First state after B2 Tasks initialization*/
        case pwmSwState_normalOperation:

            //
            //Wait for positive zero crossing: pwmSwState_positiveZeroCrossing1
            //PWM state get into positive zero crossing state1 when Vin<0.
            //TTPLPFC_threshold_PZC2=0.01,
            //
            if(TTPLPFC_acSine < TTPLPFC_threshold_PZC2
                    && TTPLPFC_acSine_Prev < 0)
            {
                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_positiveZeroCrossing1;

                //
                //Limit PU of duty.
                //
                TTPLPFC_dutyPU = 0.004f;

                //
                //Force PWM output low by AQ(LOW_FREQ) and DB(HIGH_FREQ).
                //
                TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(
                        TTPLPFC_LOW_FREQ_PWM_BASE);
                TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                      TTPLPFC_PFC_PWM_PERIOD);
                TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                      TTPLPFC_PFC_PWM_PERIOD);

                //
                //Limit output of current loop PI regulator.
                //
                TTPLPFC_gi.i10 = 0;
                TTPLPFC_gi.i6 = 1;
                TTPLPFC_gi_out = 0;

                //
                //Clear trip flags twice.
                //This flag has been cleared in B2 Tasks.
                //
                TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_LOW_FREQ_PWM_BASE);
                TTPLPFC_HAL_clearPWMTripFlags(TTPLPFC_HIGH_FREQ_PWM_BASE);

                //
                //Initialize current loop reference.
                //
                TTPLPFC_ac_cur_ref_inst_pu = 0.00f;

                //
                //Set close loop flags. Begin close loop actions.
                //
                TTPLPFC_closeGiLoop = 1;
                TTPLPFC_closeGvLoop = 1;
            }
            break;

        /*Positive half state*/
        case pwmSwState_positiveHalf:

            //
            //Set LOW_FREQ PWM output to control current direction.
            //Set DBRED to allow HIGH_FREQ PWM output.
            //
            TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_HIGH(TTPLPFC_LOW_FREQ_PWM_BASE);
            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_dbRED_SetValue_ticks);


        #if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
            if(TTPLPFC_guiPrms_W > 480 && TTPLPFC_highPowerTrans_flag == 0)
            {
                TTPLPFC_gi.Kp = TTPLPFC_GI_PI_KP_CLAH;
                TTPLPFC_gi_pi_ki = TTPLPFC_GI_PI_KI_CLAH;
                TTPLPFC_gi.Ki = TTPLPFC_gi_pi_ki;
                TTPLPFC_highPowerTrans_flag = 1;
            }
            else if(TTPLPFC_guiPrms_W < 430 && TTPLPFC_highPowerTrans_flag == 1)
            {
                TTPLPFC_gi.Kp = TTPLPFC_GI_PI_KP_CLAL;
                TTPLPFC_gi_pi_ki = TTPLPFC_GI_PI_KI_CLAL;
                TTPLPFC_gi.Ki = TTPLPFC_gi_pi_ki;
                TTPLPFC_highPowerTrans_flag = 0;
            }
        #endif

            //
            //TTPLPFC_threshold_NZC1=0.01,
            //when TTPLPFC_ac_sign_filtered == 0, Vin is negative.
            //
            if(TTPLPFC_acSine < TTPLPFC_threshold_NZC1 ||
                    TTPLPFC_ac_sign_filtered == 0)
                {

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                            pwmSwState_negativeZeroCrossing1;
                //
                //AQCSFRC xA LOW, xB LOW
                //
                TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(
                            TTPLPFC_LOW_FREQ_PWM_BASE);
                }
            break;
        /*NZC state1:*/
        case pwmSwState_negativeZeroCrossing1 :

            //
            //TTPLPFC_stateSlew++;
            //Force high_freq PWM output low by DB(HIGH_FREQ).
            //
            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            //
            //Limit PU of duty.
            //
            TTPLPFC_dutyPU = 0.004f;

            if(TTPLPFC_acSine <= 0 )
            {

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_negativeZeroCrossing2;
            }
            break;

        /*NZC state2:*/
        case pwmSwState_negativeZeroCrossing2 :

            //
            //TTPLPFC_stateSlew++;
            //Limit PU of duty.
            //
            TTPLPFC_dutyPU = 0.004f;
            if(TTPLPFC_acSine < TTPLPFC_threshold_NZC2)
            {
                //
                //Initialize two flags. Use in control DBFED in NZC3.
                //
                TTPLPFC_stateSlew = 0;
                TTPLPFC_softStartDuty_ticks = 0;

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_negativeZeroCrossing3;

                //
                //Enable xA xB Swap
                //
                TTPLPFC_ENABLE_SWAP_DEADBAND_OUTPUT(TTPLPFC_HIGH_FREQ_PWM_BASE);

                //
                //PI parameter use in PZC3 state.
                //
                TTPLPFC_gi.i10 = 0;
                TTPLPFC_gi.i6 = 1;
                TTPLPFC_gi.Ki = 0;
                TTPLPFC_gi_out = 0;
            }
            break;

        /*NZC state3:*/
        case pwmSwState_negativeZeroCrossing3 :

            //
            //Control DBFED.
            //
            TTPLPFC_softStartDuty_ticks = TTPLPFC_softStartDuty_ticks + 1;
            TTPLPFC_softStartDeadBandFED_ticks = TTPLPFC_PFC_PWM_PERIOD
                    - TTPLPFC_softStartDuty_ticks * 50;

            //
            //Limit DBFED.
            //TTPLPFC_dbFED_SetValue_ticks=10
            //
            if(TTPLPFC_softStartDeadBandFED_ticks <
                    TTPLPFC_dbFED_SetValue_ticks)
            {
                TTPLPFC_softStartDeadBandFED_ticks =
                        TTPLPFC_dbFED_SetValue_ticks;
            }

            //
            //Set DBFED=500?.
            //
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_softStartDeadBandFED_ticks );

            //
            //Count work times in PZC3.
            //
            TTPLPFC_stateSlew++;

//
//            if( fabsf(TTPLPFC_dutyPU) <  0.004f)
//            {
//                    if(TTPLPFC_dutyPU > 0)      TTPLPFC_dutyPU = 0.004;
//                    else                        TTPLPFC_dutyPU = -0.004;
//             }
//

            //
            //TTPLPFC_stateSlew>10&&Vin<0
            //
            if(TTPLPFC_stateSlew > TTPLPFC_stateSlewMax
                    && TTPLPFC_ac_sign_filtered == 0)
            {

                //
                //PI parameter use in PZC3 state.
                //
                TTPLPFC_gi.i10 = 0;
                TTPLPFC_gi.i6 = 1;
                TTPLPFC_gi.Ki = TTPLPFC_gi_pi_ki;
                TTPLPFC_gi.Umax = TTPLPFC_GI_PI_MAX;
                TTPLPFC_gi.Umin = TTPLPFC_GI_PI_MIN;
                TTPLPFC_gi_out = 0;

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_negativeHalf;

                //
                //Set DBFED=10
                //
                TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                      TTPLPFC_dbFED_SetValue_ticks);

                //
                //Reset flags.
                //
                TTPLPFC_softStartDuty_ticks = 0;
                TTPLPFC_stateSlew = 0;
            }
            break;

        /*Negative half state*/
        case pwmSwState_negativeHalf:

            //
            //Set LOW_FREQ PWM output to control current direction.
            //Set DBRED to allow HIGH_FREQ PWM output.
            //
            TTPLPFC_AQ_SW_FORCE_PWMxA_HIGH_PWMxB_LOW(TTPLPFC_LOW_FREQ_PWM_BASE);
            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_dbRED_SetValue_ticks);

            if( TTPLPFC_acSine > TTPLPFC_threshold_PZC1
                    || TTPLPFC_ac_sign_filtered == 1)
            {

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_positiveZeroCrossing1;

                //
                //AQCSFRC xA LOW, xB LOW
                //
                TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(
                        TTPLPFC_LOW_FREQ_PWM_BASE);

            }
            break;

        /*PZC state1:*/
        case pwmSwState_positiveZeroCrossing1 :

            //
            //TTPLPFC_stateSlew++; //DONOTUSE
            //Force high_freq PWM output low by DB(HIGH_FREQ).
            //
            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);

            //
            //Limit PU of duty.
            //
            TTPLPFC_dutyPU = 0.004f;
            if(TTPLPFC_acSine >= 0 )
            {
                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_positiveZeroCrossing2;
            }
            break;

        /*PZC state2:*/
        case pwmSwState_positiveZeroCrossing2 :

            //
            //TTPLPFC_stateSlew++;//DONOTUSE
            //Limit PU of duty.
            //
            TTPLPFC_dutyPU = 0.004f;
            if(TTPLPFC_acSine > TTPLPFC_threshold_PZC2 )
            {
                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState =
                        pwmSwState_positiveZeroCrossing3;

                //
                //Initialize two flags. Use in control DBFED in PZC3.
                //
                TTPLPFC_stateSlew = 0;
                TTPLPFC_softStartDuty_ticks = 0;

                //
                //Dead band output swap disabled.
                //
                TTPLPFC_DISABLE_SWAP_DEADBAND_OUTPUT(
                        TTPLPFC_HIGH_FREQ_PWM_BASE);

                //
                //PI parameter use in PZC3 state.
                //
                TTPLPFC_gi.i10 = 0;
                TTPLPFC_gi.i6 = 1;
                TTPLPFC_gi_out = 0;
                TTPLPFC_gi.Ki = 0;
            }
            break;

        /*PZC state3:*/
        case pwmSwState_positiveZeroCrossing3 :

            //
            //Control DBFED.
            // TTPLPFC_PFC_PWM_PERIOD = 1000
            //
            TTPLPFC_softStartDuty_ticks = TTPLPFC_softStartDuty_ticks + 1;
            TTPLPFC_softStartDeadBandFED_ticks = TTPLPFC_PFC_PWM_PERIOD -
                    TTPLPFC_softStartDuty_ticks * 50;

            //
            //Limit DBFED.
            //
            if(TTPLPFC_softStartDeadBandFED_ticks <
                    TTPLPFC_dbFED_SetValue_ticks )
            {
                TTPLPFC_softStartDeadBandFED_ticks =
                        TTPLPFC_dbFED_SetValue_ticks;
            }

            //
            //Set DBFED=500?.
            //
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_softStartDeadBandFED_ticks);
            //
            //Count work times in PZC3.
            //
            TTPLPFC_stateSlew++;

//
//            if( fabsf(TTPLPFC_dutyPU) <  0.004f)
//            {
//                    if(TTPLPFC_dutyPU > 0)      TTPLPFC_dutyPU = 0.004;
//                    else                        TTPLPFC_dutyPU = -0.004;
//             }
//

            //
            //TTPLPFC_stateSlew>10&&Vin>0
            //
            if(TTPLPFC_stateSlew > TTPLPFC_stateSlewMax
                      && TTPLPFC_ac_sign_filtered == 1)
            {
                //
                //PI parameters use in positive half.
                //
                TTPLPFC_gi.i10 = 0;
                TTPLPFC_gi.i6 = 1;
                TTPLPFC_gi_out = 0;
                TTPLPFC_gi.Ki = TTPLPFC_gi_pi_ki;

                //
                //State switch.
                //
                TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_positiveHalf;

                //
                //Set DBFED=10
                //
                TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                      TTPLPFC_dbFED_SetValue_ticks);

                //
                //Reset flags.
                //
                TTPLPFC_stateSlew = 0;
                TTPLPFC_softStartDuty_ticks = 0;
            }

            break;
        /*Protect state: OCP OVP*/
        case pwmSwState_defaultState:
            //
            //Limit PU of duty.
            //
            TTPLPFC_dutyPU = 0.01f;

            //
            //Force PWM output low by AQ(LOW_FREQ) and DB(HIGH_FREQ).
            //
            TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(TTPLPFC_LOW_FREQ_PWM_BASE);
            TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                                  TTPLPFC_PFC_PWM_PERIOD);
            break;

        default:
            TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;
    }

#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_pwmDriver_DC)
static inline void TTPLPFC_pwmDriver_DC()
{
#if TTPLPFC_DC_CHECK == 1
    if(TTPLPFC_ac_vol_sensed_pu > 0 && TTPLPFC_dutyPU > 0)
    {
        //
        //AQCSFRC xA LOW, xB HIGH
        //
        TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_HIGH(TTPLPFC_LOW_FREQ_PWM_BASE);

        TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                              TTPLPFC_dbRED_SetValue_ticks);
        TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                              TTPLPFC_dbFED_SetValue_ticks);

        //
        // Dead band output swap disabled
        //
        TTPLPFC_DISABLE_SWAP_DEADBAND_OUTPUT(TTPLPFC_HIGH_FREQ_PWM_BASE);
    }
    else if((TTPLPFC_ac_vol_sensed_pu < 0 && TTPLPFC_dutyPU < 0))
    {
        //
        //AQCSFRC xA HIGH, xB LOW
        //
        TTPLPFC_AQ_SW_FORCE_PWMxA_HIGH_PWMxB_LOW(TTPLPFC_LOW_FREQ_PWM_BASE);

        TTPLPFC_SET_PWM_DBRED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                              TTPLPFC_dbRED_SetValue_ticks);
        TTPLPFC_SET_PWM_DBFED(TTPLPFC_HIGH_FREQ_PWM_BASE,
                              TTPLPFC_dbFED_SetValue_ticks);

        //
        // Dead band output swap enabled
        //
        TTPLPFC_ENABLE_SWAP_DEADBAND_OUTPUT(TTPLPFC_HIGH_FREQ_PWM_BASE);
    }
    TTPLPFC_dutyPU = (TTPLPFC_dutyPU < (float32_t)(0.0f))?
                     (float32_t)(0.0f):TTPLPFC_dutyPU;
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_adaptiveDeadTime)
static inline void TTPLPFC_adaptiveDeadTime()
{
#if TTPLPFC_ADAPTIVE_DEADTIME == 1
    TTPLPFC_iLMeasScaled_Amps = fabsf(TTPLPFC_ac_cur_sensed_pu
                                      * TTPLPFC_IL_MAX_SENSE_AMPS);
    TTPLPFC_iLMeasScaled_Amps = (TTPLPFC_iLMeasScaled_Amps < 0.01f) ? 0.01f:
            TTPLPFC_iLMeasScaled_Amps;

    TTPLPFC_dbRED_SetValue_Temp_ticks = (uint16_t)(
                            (float32_t)100000000.0 * (2.0f *
                            TTPLPFC_VBUS_TYPICAL_VOLT * TTPLPFC_GAN_COSS) /
                            (TTPLPFC_iLMeasScaled_Amps * 0.33f)
                            );

    TTPLPFC_dbRED_SetValue_ticks = (TTPLPFC_dbRED_SetValue_Temp_ticks <
            TTPLPFC_dbRED_Min_ticks)?TTPLPFC_dbRED_Min_ticks:
            TTPLPFC_dbRED_SetValue_Temp_ticks;
    TTPLPFC_dbRED_SetValue_ticks = (TTPLPFC_dbRED_SetValue_Temp_ticks >
                     TTPLPFC_dbRED_Max_ticks)?TTPLPFC_dbRED_Max_ticks:
                     TTPLPFC_dbRED_SetValue_Temp_ticks;
#else
    TTPLPFC_dbRED_SetValue_ticks = TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_COUNT;//10
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_SPLL)
static inline void TTPLPFC_SPLL()
{
#if TTPLPFC_SPLL_METHOD_SELECT == TTPLPFC_SPLL_1PH_SOGI_SEL
    SPLL_1PH_SOGI_run(&TTPLPFC_spll1, TTPLPFC_ac_vol_sensed_pu);
    TTPLPFC_spll_sine = TTPLPFC_spll1.sine;
    TTPLPFC_spll_cosine = TTPLPFC_spll1.cosine;

    if(fabsf(TTPLPFC_spll1.ylf[0]) > 2.0f)
    {
        if(TTPLPFC_ac_vol_sensed_pu > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }
    else
    {
        if(TTPLPFC_spll1.sine > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }

    TTPLPFC_acSine_Prev = TTPLPFC_acSine;
    TTPLPFC_acSine = TTPLPFC_spll_sine;
#endif

#if TTPLPFC_SPLL_METHOD_SELECT == TTPLPFC_SPLL_1PH_NOTCH_SEL
    SPLL_1PH_NOTCH_run(&TTPLPFC_spll2, TTPLPFC_ac_vol_sensed_pu);
    TTPLPFC_spll_sine = TTPLPFC_spll2.sine;
    TTPLPFC_spll_cosine = TTPLPFC_spll2.cosine;
    if(fabsf(TTPLPFC_spll2.ylf[0]) > 8.0f)
    {

        if(TTPLPFC_ac_vol_sensed_pu > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }
    else
    {

        if(TTPLPFC_spll2.sine > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }

    TTPLPFC_acSine_Prev = TTPLPFC_acSine;
    TTPLPFC_acSine = TTPLPFC_spll_sine;
#endif


#if TTPLPFC_SPLL_METHOD_SELECT == TTPLPFC_SPLL_1PH_SOGI_FLL_SEL
  SPLL_1PH_SOGI_FLL_run(&TTPLPFC_spll3, TTPLPFC_ac_vol_sensed_pu);
  TTPLPFC_spll_sine = TTPLPFC_spll3.sine;
  TTPLPFC_spll_cosine = TTPLPFC_spll3.cosine;

    if(fabsf(TTPLPFC_spll3.ylf[0]) > 0.8f)
    {
        if(TTPLPFC_ac_vol_sensed_pu > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }
    else
    {


        if(TTPLPFC_spll3.sine > 0.0f)
        {
            TTPLPFC_ac_sign_filtered = 1;
        }
        else
        {
            TTPLPFC_ac_sign_filtered = 0;
        }
    }

    TTPLPFC_acSine_Prev = TTPLPFC_acSine;
    TTPLPFC_acSine = TTPLPFC_spll_sine;
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_dataLogger)
static inline void TTPLPFC_dataLogger()
{
#ifndef __TMS320C28XX_CLA__

    #if TTPLPFC_LAB == 1
        TTPLPFC_dVal1 = TTPLPFC_ac_cur_sensed_pu;
        TTPLPFC_dVal2 = TTPLPFC_ac_L_sensed_pu;
        TTPLPFC_dVal3 = TTPLPFC_ac_N_sensed_pu;
        TTPLPFC_dVal4 = TTPLPFC_dutyPU;
    #elif TTPLPFC_LAB == 2
        TTPLPFC_dVal1 = TTPLPFC_gi_out;
        TTPLPFC_dVal2 = TTPLPFC_ac_vol_sensed_pu;
        TTPLPFC_dVal3 = TTPLPFC_iLVrefMeas_pu;
        TTPLPFC_dVal4 = TTPLPFC_ac_cur_sensed_pu;
    #else
        TTPLPFC_dVal1 = TTPLPFC_guiVrms_Volts;
        TTPLPFC_dVal2 = TTPLPFC_guiVin_Volts;
        TTPLPFC_dVal3 = TTPLPFC_dutyPU;
        TTPLPFC_dVal4 = TTPLPFC_ac_vol_sensed_pu;

    #endif
    DLOG_4CH_run(&TTPLPFC_dLog1);
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_rlyConnectFlag)
static inline void TTPLPFC_rlyConnectFlag()
{
#if TTPLPFC_DC_CHECK == 0
    if(TTPLPFC_guiVrms_Volts > 75.0f || TTPLPFC_guiVbus_Volts > 110.0f)
    {
        TTPLPFC_relayConnect = 1;
    }
    else
    {
        TTPLPFC_relayConnect = 0;
    }
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_overVoltageProtection)
static inline void TTPLPFC_overVoltageProtection()
{
    if(TTPLPFC_guiVbus_Volts > TTPLPFC_guiVbusMax_Volts)
    {
        TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;

        TTPLPFC_HAL_forceOSTPWMTrip(TTPLPFC_HIGH_FREQ_PWM_BASE);

        EPWM_setActionQualifierContSWForceAction(TTPLPFC_LOW_FREQ_PWM_BASE,
                                                EPWM_AQ_OUTPUT_A ,
                                                EPWM_AQ_SW_OUTPUT_LOW);
        EPWM_setActionQualifierContSWForceAction(TTPLPFC_LOW_FREQ_PWM_BASE,
                                                EPWM_AQ_OUTPUT_B ,
                                                EPWM_AQ_SW_OUTPUT_LOW);

        if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
        {
            TTPLPFC_ac_volRmsEma_sensed_Volts = 0;
        }
        TTPLPFC_board_Status.enum_boardStatus = boardStatus_OverVoltageTrip;
    }
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_underVoltageProtection)
static inline void TTPLPFC_underVoltageProtection()
{
#if TTPLPFC_DC_CHECK == 0
     if(TTPLPFC_guiVrms_Volts < 75.0f)  //ToDO 75
        {
            TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;

            TTPLPFC_HAL_forceOSTPWMTrip(TTPLPFC_HIGH_FREQ_PWM_BASE);

            EPWM_setActionQualifierContSWForceAction(TTPLPFC_LOW_FREQ_PWM_BASE,
                                                    EPWM_AQ_OUTPUT_A ,
                                                    EPWM_AQ_SW_OUTPUT_LOW);
            EPWM_setActionQualifierContSWForceAction(TTPLPFC_LOW_FREQ_PWM_BASE,
                                                    EPWM_AQ_OUTPUT_B ,
                                                    EPWM_AQ_SW_OUTPUT_LOW);

            if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
            {
                TTPLPFC_ac_volRmsEma_sensed_Volts = 0;
            }
            TTPLPFC_board_Status.enum_boardStatus =
                    boardStatus_InputUnderVoltageTrip;
        }
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_overCurrentProtection)
static inline void TTPLPFC_overCurrentProtection()
{
    if((TTPLPFC_PWM_TRIP_STATUS(TTPLPFC_LOW_FREQ_PWM_BASE) &
            EPWM_TZ_INTERRUPT_DCAEVT1) != 0)
    {
        TTPLPFC_pwm_SwState.enum_pwmSwState = pwmSwState_defaultState;

        if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
        {
            TTPLPFC_ac_volRmsEma_sensed_Volts = 0;
        }

        TTPLPFC_board_Status.enum_boardStatus = boardStatus_OverCurrentTrip;
    }
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_instrumentation)
static inline void TTPLPFC_instrumentation()
{
    //
    //Calculate RMS input voltage and input frequency
    //
    TTPLPFC_sine_mains.i = TTPLPFC_ac_cur_sensed_pu;
    TTPLPFC_sine_mains.v = TTPLPFC_ac_vol_sensed_pu;
    POWER_MEAS_SINE_ANALYZER_run(&TTPLPFC_sine_mains);
    TTPLPFC_guiIrms_Amps = TTPLPFC_sine_mains.iRms *
                           TTPLPFC_IL_MAX_SENSE_AMPS;
    TTPLPFC_guiVrms_Volts = TTPLPFC_sine_mains.vRms *
                            TTPLPFC_VAC_MAX_SENSE_VOLT;
    TTPLPFC_guiPrms_W = TTPLPFC_sine_mains.pRms *
                        TTPLPFC_VAC_MAX_SENSE_VOLT *
                        TTPLPFC_IL_MAX_SENSE_AMPS;
    TTPLPFC_guiPowerFactor = TTPLPFC_sine_mains.powerFactor;
    TTPLPFC_guiVA_VA = TTPLPFC_sine_mains.vaRms *
                       TTPLPFC_VAC_MAX_SENSE_VOLT *
                       TTPLPFC_IL_MAX_SENSE_AMPS;
    TTPLPFC_guiFreqAvg_Hz = TTPLPFC_sine_mains.acFreqAvg;
    TTPLPFC_guiVema_Volts = TTPLPFC_sine_mains.vEma *
                            TTPLPFC_VAC_MAX_SENSE_VOLT;

    EMAVG_MACRO(TTPLPFC_sine_mains.vRms,
                TTPLPFC_vACRmsMeasAvg_pu,
                (float32_t)0.000528);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_rlyOnOff)
static inline void TTPLPFC_rlyOnOff()
{
#if TTPLPFC_DC_CHECK == 0
    if(fabsf(TTPLPFC_acSine) < 0.05f)
    {
        if(TTPLPFC_relayConnect == 1)
        {
            TTPLPFC_HAL_closeRelay();
        }
    }

    if(TTPLPFC_relayConnect == 0)
    {
        TTPLPFC_HAL_openRelay();
    }
#else
    if(TTPLPFC_relayConnect == 1)
    {
        TTPLPFC_HAL_closeRelay();
    }
    else
    {
        TTPLPFC_HAL_openRelay();
    }
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runSFRAcollect)
static inline void TTPLPFC_runSFRAcollect(void)
{
#if(TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_CURRENT )
    SFRA_F32_collect((float32_t*) &TTPLPFC_gi_out,
                     (float32_t*) &TTPLPFC_ac_cur_sensed_pu);
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runHighResolutionGraph)
static inline void TTPLPFC_runHighResolutionGraph(void)
{
#if TTPLPFC_DEBUG_CHIP == F28004X
    if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
    {
        TTPLPFC_faultTriggerFlag2 = 0;
    }
    else
    {
        TTPLPFC_faultTriggerFlag2 = 1;
    }
    if(1)//TTPLPFC_graphArrayWatchValue1
    {
        TTPLPFC_graphArrayWatchValue3[TTPLPFC_graphArrayWatchValueindex2] =
                TTPLPFC_ac_cur_sensed_pu;
        TTPLPFC_graphArrayWatchValue4[TTPLPFC_graphArrayWatchValueindex2] =
                TTPLPFC_dutyPU;
        TTPLPFC_graphArrayWatchValueindex2++;
        if(TTPLPFC_graphArrayWatchValueindex2 == 2000)
            TTPLPFC_graphArrayWatchValueindex2 = 0;
    }
#endif
}


#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runLowResolutionGraph)
static inline void TTPLPFC_runLowResolutionGraph(void)
{
#if TTPLPFC_DEBUG_CHIP == F28004X
    if(TTPLPFC_board_Status.enum_boardStatus == boardStatus_NoFault)
    {
        TTPLPFC_faultTriggerFlag1 = 0;
    }
    else
    {
        TTPLPFC_faultTriggerFlag1 = 1;
    }
    if(TTPLPFC_faultTriggerFlag1 == 0)//
    {
        TTPLPFC_graphArrayWatchValue1[TTPLPFC_graphArrayWatchValueindex1] =
                TTPLPFC_ac_cur_ref_pu;
        TTPLPFC_graphArrayWatchValue2[TTPLPFC_graphArrayWatchValueindex1] =
                TTPLPFC_vBus_sensedFiltered_notch2;
        TTPLPFC_graphArrayWatchValueindex1++;
        if(TTPLPFC_graphArrayWatchValueindex1 == 1600)
            TTPLPFC_graphArrayWatchValueindex1 = 0;
    }
#endif
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_controlLLCStatus)
static inline void TTPLPFC_controlLLCStatus(void)
{
    if(((TTPLPFC_PWM_TRIP_STATUS(TTPLPFC_LOW_FREQ_PWM_BASE)
            &EPWM_TZ_FLAG_OST)!=0) |
       ((TTPLPFC_PWM_TRIP_STATUS(TTPLPFC_HIGH_FREQ_PWM_BASE)
            &EPWM_TZ_FLAG_OST)!=0))
    {
        TTPLPFC_HAL_shutdownLLC();
        TTPLPFC_llcShutdownFlag = 1;
    }
    else
    {
        TTPLPFC_llcShutdownFlag = 0;
    }
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runFsiTxISR1)
static inline void TTPLPFC_runFsiTxISR1(void)
{
    TTPLPFC_fsiTxInt1Received = 1U;

    TTPLPFC_txEventSts = FSI_getTxEventStatus(FSITXA_BASE);

    // Set FSI TX circular buffer pointer back to beginning
    FSI_setTxBufferPtr(FSITXA_BASE, 0U);

    //
    // Clear the interrupt flag and issue ACK
    //
    FSI_clearTxEvents(FSITXA_BASE, FSI_TX_EVTMASK);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runFsiTxISR2)
static inline void TTPLPFC_runFsiTxISR2(void)
{
    TTPLPFC_fsiTxInt2Received = 1U;

    TTPLPFC_txEventSts = FSI_getTxEventStatus(FSITXA_BASE);

    //
    // Clear the interrupt flag and issue ACK
    //
    FSI_clearTxEvents(FSITXA_BASE, FSI_TX_EVTMASK);

    //
    // INT2 line is set to fire for error events, stop immediately. Actual Error
    // is captured in txEventSts for debug
    //
    ESTOP0;
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runFsiTxISR1)
static inline void TTPLPFC_runFsiRxISR1(void)
{
    TTPLPFC_rxEventSts = FSI_getRxEventStatus(FSIRXA_BASE);

    TTPLPFC_fsiRxInt1Received = 1U;

    //
    // Clear the interrupt flag and issue ACK
    //
    FSI_clearRxEvents(FSIRXA_BASE, TTPLPFC_rxEventSts);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runFsiTxISR1)
static inline void TTPLPFC_runFsiRxISR2(void)
{
    TTPLPFC_rxEventSts = FSI_getRxEventStatus(FSIRXA_BASE);

    TTPLPFC_fsiRxInt2Received = TTPLPFC_fsiRxInt2Received + 1U;

    //
    // Clear the interrupt flag and issue ACK
    //
    FSI_clearRxEvents(FSIRXA_BASE, TTPLPFC_rxEventSts);

    //
    // INT2 line is set to fire for error events, stop immediately. Error
    // is captured in rxEventSts for debug
    //
    ESTOP0;
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runISR1_lab1)
static inline void TTPLPFC_runISR1_lab1(void)
{
    //
    // Read Current and Input Voltage Measurements.
    //
    TTPLPFC_read_acReturnCurrent();
    TTPLPFC_read_acVoltage_separateResistor();

    //
    // PWM Driver
    //
#pragma diag_suppress = 770
#pragma diag_suppress = 173
    TTPLPFC_rampGenerate();
    #if TTPLPFC_DC_CHECK == 1
        TTPLPFC_dutyPU = TTPLPFC_dutyPU_DC;
    #else
        TTPLPFC_dutyPU = TTPLPFC_dutyPU_DC * TTPLPFC_acSine;
    #endif

    //
    // PWM state driver.
    //
    TTPLPFC_pwmDriver_DC();

    //
    //Set CMPA to generate PWM waveform.
    //
    TTPLPFC_HAL_updatePWM(TTPLPFC_LOW_FREQ_PWM_BASE,
                          TTPLPFC_HIGH_FREQ_PWM_BASE,
                          TTPLPFC_dutyPU,
                          TTPLPFC_phase2ScaleFactor);

#pragma diag_warning = 770
#pragma diag_warning = 173

    //
    // Adaptive deadtime.
    //
    TTPLPFC_adaptiveDeadTime();

    //
    //Read BUS voltage sensed result.
    //
    TTPLPFC_read_busVoltage();
    TTPLPFC_vBusMeasBuff_pu[TTPLPFC_vBusMeasBuffIndex++]
                            = TTPLPFC_vBus_sensed_pu;
    if(TTPLPFC_vBusMeasBuffIndex >= 10)
        TTPLPFC_vBusMeasBuffIndex = 0;

    //
    // Graph array to show waveform of memory.
    //
    TTPLPFC_runHighResolutionGraph();

    TTPLPFC_HAL_clearPWMInterruptFlag(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runISR1_lab2)
static inline void TTPLPFC_runISR1_lab2(void)
{
    //
    //Read Current and Input Voltage Measurements.
    //Run current loop.
    //
    TTPLPFC_read_acReturnCurrent();
    TTPLPFC_read_acVoltage_separateResistor();
    TTPLPFC_runCurrentLoop();

#pragma diag_suppress = 770
#pragma diag_suppress = 173

    //
    // PWM state driver.
    //
    TTPLPFC_pwmDriver_DC();
    //
    //Set CMPA to generate PWM waveform.
    //
    TTPLPFC_HAL_updatePWM(TTPLPFC_LOW_FREQ_PWM_BASE,
                          TTPLPFC_HIGH_FREQ_PWM_BASE,
                          TTPLPFC_dutyPU,
                          TTPLPFC_phase2ScaleFactor);

#pragma diag_warning = 770
#pragma diag_warning = 173

    //
    // Adaptive deadtime.
    //
    TTPLPFC_adaptiveDeadTime();

    //
    //Current loop reference.
    //
    TTPLPFC_acCurrentRef();

    //
    // SFRA collect point.
    //
    TTPLPFC_runSFRAcollect();

    //
    //Read BUS voltage sensed result.
    //
    TTPLPFC_read_busVoltage();
    TTPLPFC_vBusMeasBuff_pu[TTPLPFC_vBusMeasBuffIndex++]
                            = TTPLPFC_vBus_sensed_pu;
    if(TTPLPFC_vBusMeasBuffIndex >= 10)
        TTPLPFC_vBusMeasBuffIndex = 0;

    //
    // Graph array to show waveform in memory.
    //
    TTPLPFC_runHighResolutionGraph();

    TTPLPFC_HAL_clearPWMInterruptFlag(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runISR1_lab3)
static inline void TTPLPFC_runISR1_lab3(void)
{
    //
    //Read Current and Input Voltage Measurements.
    //Run current loop.
    //
    TTPLPFC_read_acReturnCurrent();
    TTPLPFC_read_acVoltage_separateResistor();
    TTPLPFC_runCurrentLoop();

#pragma diag_suppress = 770
#pragma diag_suppress = 173

    //
    // PWM state driver.
    //
    TTPLPFC_pwmDriver();

    //
    //Set CMPA to generate PWM waveform.
    //
    TTPLPFC_HAL_updatePWM(TTPLPFC_LOW_FREQ_PWM_BASE,
                          TTPLPFC_HIGH_FREQ_PWM_BASE,
                          TTPLPFC_dutyPU,
                          TTPLPFC_phase2ScaleFactor);
#pragma diag_warning = 770
#pragma diag_warning = 173

    //
    // Adaptive deadtime.
    //
    TTPLPFC_adaptiveDeadTime();

    //
    // Software phase lock loop.
    //
    TTPLPFC_SPLL();

    //
    //Set current loop reference:
    //TTPLPFC_ac_cur_ref_inst_pu (contain phase information)
    //
    TTPLPFC_acCurrentRef();

    //
    // SFRA collect point.
    //
    TTPLPFC_runSFRAcollect();

    //
    //Read BUS voltage sensed result.
    //
    TTPLPFC_read_busVoltage();
    TTPLPFC_vBusMeasBuff_pu[TTPLPFC_vBusMeasBuffIndex++] =
            TTPLPFC_vBus_sensed_pu;
    if(TTPLPFC_vBusMeasBuffIndex >= 10)
        TTPLPFC_vBusMeasBuffIndex = 0;

    //
    // Graph array to show waveform in memory.
    //
    TTPLPFC_runHighResolutionGraph();

    TTPLPFC_HAL_clearPWMInterruptFlag(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);
}

#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runISR1_lab4)
static inline void TTPLPFC_runISR1_lab4(void)
{
    //
    //Read Current and Input Voltage Measurements.
    //
    TTPLPFC_read_acReturnCurrent();
    TTPLPFC_read_acVoltage_separateResistor();
    TTPLPFC_runCurrentLoop();

#pragma diag_suppress = 770
#pragma diag_suppress = 173

    //
    // PWM state driver.
    //
    TTPLPFC_pwmDriver();

    //
    //Set CMPA to generate PWM waveform.
    //
    TTPLPFC_HAL_updatePWM(TTPLPFC_LOW_FREQ_PWM_BASE,
                          TTPLPFC_HIGH_FREQ_PWM_BASE,
                          TTPLPFC_dutyPU,
                          TTPLPFC_phase2ScaleFactor);
#pragma diag_warning = 770
#pragma diag_warning = 173

    //
    // Adaptive deadtime.
    //
    TTPLPFC_adaptiveDeadTime();

    //
    // Software phase lock loop.
    //
    TTPLPFC_SPLL();

    //
    //Set current loop reference:
    // TTPLPFC_ac_cur_ref_inst_pu (contain phase information)
    //
    TTPLPFC_acCurrentRef();

    //
    // SFRA collect point.
    //
    TTPLPFC_runSFRAcollect();

    //
    //Read BUS voltage sensed result.
    //
    TTPLPFC_read_busVoltage();
    TTPLPFC_vBusMeasBuff_pu[TTPLPFC_vBusMeasBuffIndex++] =
            TTPLPFC_vBus_sensed_pu;
    if(TTPLPFC_vBusMeasBuffIndex >= 10)
        TTPLPFC_vBusMeasBuffIndex = 0;

    //
    // Graph array to show waveform in memory.
    //
    TTPLPFC_runHighResolutionGraph();

    TTPLPFC_HAL_clearPWMInterruptFlag(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);
}


#pragma FUNC_ALWAYS_INLINE(TTPLPFC_runISR2)
static inline void TTPLPFC_runISR2()
{
    int32_t vBusSensedBuffIndex1 = 0;
    #if TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON == C28x_CORE
        EINT;
    #endif

//#if TTPLPFC_LAB == 4
//    //
//    //Monitor PFC stage, if OCP, send LLC shutdown signal.
//    //
//    TTPLPFC_controlLLCStatus();
//#endif

    //
    //Filter the BUS voltage sensed result.
    //
    TTPLPFC_vBusMeasFiltered_pu = 0;
    for(vBusSensedBuffIndex1 = 0;
        vBusSensedBuffIndex1 < 10;
        vBusSensedBuffIndex1++)
    {
        TTPLPFC_vBusMeasFiltered_pu +=
                TTPLPFC_vBusMeasBuff_pu[vBusSensedBuffIndex1];
    }
    TTPLPFC_vBusMeasFiltered_pu = TTPLPFC_vBusMeasFiltered_pu * 0.1f;
    TTPLPFC_vBus_sensedFiltered_notch1 = NOTCH_2P2Z_RUN(&TTPLPFC_notch1,
                                         TTPLPFC_vBusMeasFiltered_pu);
    TTPLPFC_vBus_sensedFiltered_notch2 = NOTCH_2P2Z_RUN(&TTPLPFC_notch2,
                                         TTPLPFC_vBus_sensedFiltered_notch1);

//
//LAB 4 Close voltage loop and build bus voltage softly.
//
#if(TTPLPFC_LAB == 4)

    TTPLPFC_runVoltageLoop();

#endif

    EMAVG_MACRO(TTPLPFC_vBus_sensedFiltered_notch2,
                TTPLPFC_vBusAvg_pu, (float32_t)0.000528);
    EMAVG_MACRO((fabsf(TTPLPFC_ac_vol_sensed_pu) * TTPLPFC_VAC_MAX_SENSE_VOLT),
                TTPLPFC_ac_volRmsEma_sensed_Volts, (float32_t)0.00005);


    //
    //    Connect inputs of the Datalogger module
    //
    TTPLPFC_dataLogger();

    TTPLPFC_rlyConnectFlag();
    //
    //GUI variables calculation and protect process.
    //
    TTPLPFC_guiVbus_Volts = TTPLPFC_vBus_sensedFiltered_notch2 *
                            TTPLPFC_VDCBUS_MAX_SENSE_VOLT;
    TTPLPFC_guiVin_Volts = (TTPLPFC_ac_vol_sensed_pu) *
                            TTPLPFC_VAC_MAX_SENSE_VOLT;
    TTPLPFC_guiIL_Amps = TTPLPFC_ac_cur_sensed_pu * TTPLPFC_IL_MAX_SENSE_AMPS;

    TTPLPFC_overVoltageProtection();
    TTPLPFC_underVoltageProtection();
    TTPLPFC_overCurrentProtection();

    TTPLPFC_instrumentation();

    TTPLPFC_rlyOnOff();

    TTPLPFC_runLowResolutionGraph();
}



#ifdef __cplusplus
}
#endif                                  /* extern "C" */

#endif
