//#############################################################################
//
// FILE:  ttplpfc_hal.h
//
// TITLE: Solution hardware abstraction layer
//        Low level functions and resources with hardware dependencies
//        Example: Functions to read current and voltage signals
//        Example: Functions to configure device peripherals
//
//#############################################################################
//#############################################################################
// $TI Release: TIDA_010062 v2.02.00.00 $
// $Release Date: Fri Oct  6 19:11:54 CDT 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

#ifndef TTPLPFC_HAL_H
#define TTPLPFC_HAL_H

#ifdef __cplusplus

extern "C" {
#endif


//
// the includes
//
#include <stdint.h>
#include "inc/hw_types.h"
#include "driverlib.h"
#include "device.h"
#include <ttplpfc_settings.h>

//
//defines
//

/*******************************HAL_ADC*******************************/
//
//ADC result
//
#define TTPLPFC_VBUS_FB_1     ADC_readResult(TTPLPFC_VBUS_ADCRESULTREGBASE, TTPLPFC_VBUS_ADC_SOC_NO_1)
#define TTPLPFC_VBUS_FB_2     ADC_readResult(TTPLPFC_VBUS_ADCRESULTREGBASE, TTPLPFC_VBUS_ADC_SOC_NO_2)

#define TTPLPFC_IL_FB_1       ADC_readResult(TTPLPFC_IL_ADCRESULTREGBASE, TTPLPFC_IL_ADC_SOC_NO_1)
#define TTPLPFC_IL_FB_2       ADC_readResult(TTPLPFC_IL_ADCRESULTREGBASE, TTPLPFC_IL_ADC_SOC_NO_2)

#define TTPLPFC_IL_VREF_FB_1  ADC_readResult(TTPLPFC_IL_VREF_ADCRESULTREGBASE, TTPLPFC_IL_VREF_ADC_SOC_NO_1)
#define TTPLPFC_IL_VREF_FB_2  ADC_readResult(TTPLPFC_IL_VREF_ADCRESULTREGBASE, TTPLPFC_IL_VREF_ADC_SOC_NO_2)

#define TTPLPFC_VAC_L_FB_1    ADC_readResult(TTPLPFC_VACL_ADCRESULTREGBASE, TTPLPFC_VACL_ADC_SOC_NO_1)
#define TTPLPFC_VAC_L_FB_2    ADC_readResult(TTPLPFC_VACL_ADCRESULTREGBASE, TTPLPFC_VACL_ADC_SOC_NO_2)

#define TTPLPFC_VAC_N_FB_1    ADC_readResult(TTPLPFC_VACN_ADCRESULTREGBASE, TTPLPFC_VACN_ADC_SOC_NO_1)
#define TTPLPFC_VAC_N_FB_2    ADC_readResult(TTPLPFC_VACN_ADCRESULTREGBASE, TTPLPFC_VACN_ADC_SOC_NO_2)

//
//ADC scale factor
//
#define TTPLPFC_ADC_PU_SCALE_FACTOR      (float32_t)(0.000244140625)//1/4096
#define TTPLPFC_ADC_PU_PPB_SCALE_FACTOR  (float32_t)(0.000488281250)//1/2^11

/*******************************HAL_Timer*******************************/
#define TTPLPFC_GET_TASK_A_TIMER_OVERFLOW_STATUS CPUTimer_getTimerOverflowStatus(CPUTIMER0_BASE)
#define TTPLPFC_CLEAR_TASK_A_TIMER_OVERFLOW_FLAG CPUTimer_clearOverflowFlag(CPUTIMER0_BASE)

#define TTPLPFC_GET_TASK_B_TIMER_OVERFLOW_STATUS CPUTimer_getTimerOverflowStatus(CPUTIMER1_BASE)
#define TTPLPFC_CLEAR_TASK_B_TIMER_OVERFLOW_FLAG CPUTimer_clearOverflowFlag(CPUTIMER1_BASE)
/*******************************HAL_EPWM*******************************/
#define TTPLPFC_DISABLE_AQ_SW_FRC(m)                 HWREGH(m + EPWM_O_AQCSFRC) = 0x00;
#define TTPLPFC_AQ_SW_FORCE_PWMxA_HIGH_PWMxB_LOW(m)  HWREGH(m + EPWM_O_AQCSFRC) = 0x06;
#define TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_HIGH(m)  HWREGH(m + EPWM_O_AQCSFRC) = 0x09;
#define TTPLPFC_AQ_SW_FORCE_PWMxA_LOW_PWMxB_LOW(m)   HWREGH(m + EPWM_O_AQCSFRC) = 0x05;
#define TTPLPFC_SET_PWM_DBRED(m, n)                  HWREGH(m + EPWM_O_DBRED ) = n;
#define TTPLPFC_SET_PWM_DBFED(m, n)                  HWREGH(m + EPWM_O_DBFED ) = n;
#define TTPLPFC_ENABLE_SWAP_DEADBAND_OUTPUT(m)       HWREGH(m + EPWM_O_DBCTL) = (HWREGH(m + EPWM_O_DBCTL) | 0x3000);
#define TTPLPFC_DISABLE_SWAP_DEADBAND_OUTPUT(m)      HWREGH(m + EPWM_O_DBCTL) = (HWREGH(m + EPWM_O_DBCTL) & ~0x3000);
#define TTPLPFC_PWM_TRIP_STATUS                      EPWM_getTripZoneFlagStatus

//
// the function prototypes
//
void TTPLPFC_HAL_setupDevice(void);

void TTPLPFC_HAL_setupADC(void);

void TTPLPFC_HAL_setupPWM(uint32_t base1,
                          uint32_t base3,
                          uint16_t pwm_period_ticks,
                          uint16_t pwm_dbred_ticks,
                          uint16_t pwm_dbfed_ticks);

void TTPLPFC_HAL_disablePWMCLKCounting(void);
void TTPLPFC_HAL_enablePWMCLKCounting(void);
void TTPLPFC_HAL_setupTrigForADC(uint32_t base);
void TTPLPFC_HAL_setPinsAsPWM();
void TTPLPFC_HAL_initFSI();

void TTPLPFC_HAL_setupBoardProtection(uint32_t base1, uint32_t base3,
                                      float32_t current_limit,
                                      float32_t current_max_sense);

void TTPLPFC_HAL_setupCMPSS(uint32_t base1,
                            float32_t current_limit,
                            float32_t current_max_sense);

void TTPLPFC_HAL_setupProfilingGPIO(void);
void TTPLPFC_HAL_setupRelayGPIO(void);
void TTPLPFC_HAL_toggleLED(void);
void TTPLPFC_HAL_setupLEDGPIO(void);
void TTPLPFC_HAL_setupGainChangeGPIO(void);
void TTPLPFC_HAL_setupStartupGPIO(void);


void TTPLPFC_HAL_setupCLA(void);

//
//CLA C Tasks defined in Cla1Tasks_C.cla
//
__attribute__((interrupt))  void Cla1Task1();
__attribute__((interrupt))  void Cla1Task2();
__attribute__((interrupt))  void Cla1Task3();
__attribute__((interrupt))  void Cla1Task4();
__attribute__((interrupt))  void Cla1Task5();
__attribute__((interrupt))  void Cla1Task6();
__attribute__((interrupt))  void Cla1Task7();
__attribute__((interrupt))  void Cla1BackgroundTask();

extern uint16_t Cla1ProgLoadStart;
extern uint16_t Cla1ProgLoadEnd;
extern uint16_t Cla1ProgLoadSize;
extern uint16_t Cla1ProgRunStart;
extern uint16_t Cla1ProgRunEnd;
extern uint16_t Cla1ProgRunSize;

//
// ISR related
//
#if TTPLPFC_CONTROL_RUNNING_ON == C28x_CORE

#ifndef __TMS320C28XX_CLA__
    #pragma INTERRUPT (ISR1, HPI)
    #pragma CODE_SECTION(ISR1,"isrcodefuncs");
    interrupt void ISR1(void);
    static inline void TTPLPFC_HAL_clearInterrupt(uint16_t pie_group_no);
    static inline void TTPLPFC_HAL_setupInterrupt(void);
#endif

#endif

#if TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON == C28x_CORE

#ifndef __TMS320C28XX_CLA__
    #pragma CODE_SECTION(ISR2,"ramfuncs");
    interrupt void ISR2(void);
    static inline void TTPLPFC_HAL_clearInterrupt(uint16_t pie_group_no);
    static inline void TTPLPFC_HAL_setupInterrupt(void);
#endif

#endif

__interrupt void fsiTxInt1ISR(void);
__interrupt void fsiTxInt2ISR(void);
__interrupt void fsiRxInt1ISR(void);
__interrupt void fsiRxInt2ISR(void);

//
// Inline functions
//

static inline void TTPLPFC_HAL_EPWM_setCounterCompareValueOptimized(
                                     uint32_t base,
                                     EPWM_CounterCompareModule compModule,
                                     uint16_t compCount)
{
    uint32_t registerOffset;

    //
    // Get the register offset for the Counter compare
    //
    registerOffset = EPWM_O_CMPA + (uint16_t)compModule;

    //
    // Write to the counter compare registers.
    //
    #pragma diag_suppress = 770
    #pragma diag_suppress = 173
    if((compModule == EPWM_COUNTER_COMPARE_A) ||
    (compModule == EPWM_COUNTER_COMPARE_B))
    {

        //
        // write to CMPA or COMPB bits
        //
        HWREGH(base + registerOffset + 1) = (uint16_t)compCount;
    }
    else
    {
        //
        // write to COMPC or COMPD bits
        //
        HWREGH(base + registerOffset) = compCount;
    }
    #pragma diag_warning = 770
    #pragma diag_warning = 173
}

static inline void TTPLPFC_HAL_FsiSendFlushSequence()
{
    FSI_executeTxFlushSequence(FSITXA_BASE, TTPLPFC_PRESCALER_VAL);
}

static inline void TTPLPFC_HAL_updatePWM(uint32_t base1,
                                         uint32_t base3,
                                         float32_t duty,
                                         float32_t phase2ScaleFactor)
{
    uint32_t dutyPWMReg;

    dutyPWMReg = (uint32_t)((float32_t)(TTPLPFC_PFC_PWM_PERIOD
                                        / 2.0f) * fabsf(duty));

    TTPLPFC_HAL_EPWM_setCounterCompareValueOptimized(base3,
                                          EPWM_COUNTER_COMPARE_A,
                                          (uint32_t)((float32_t)dutyPWMReg *
                                          (float32_t)phase2ScaleFactor));

}


static inline void TTPLPFC_HAL_setProfilingGPIO(void)
{
    #pragma diag_suppress = 770
    #pragma diag_suppress = 173
    HWREG(GPIODATA_BASE + GPIO_O_GPASET) = TTPLPFC_GPIO_PROFILING1_SET;
    #pragma diag_warning = 770
    #pragma diag_warning = 173
}


static inline void TTPLPFC_HAL_resetProfilingGPIO(void)
{
    #pragma diag_suppress = 770
    #pragma diag_suppress = 173
    HWREG(GPIODATA_BASE  + GPIO_O_GPACLEAR) = TTPLPFC_GPIO_PROFILING1_CLEAR;
    #pragma diag_warning = 770
    #pragma diag_warning = 173
}


static inline void TTPLPFC_HAL_setProfilingGPIO2(void)
{
    #pragma diag_suppress = 770
    #pragma diag_suppress = 173
    HWREG(GPIODATA_BASE + GPIO_O_GPASET) = TTPLPFC_GPIO_PROFILING2_SET;
    #pragma diag_warning = 770
    #pragma diag_warning = 173
}


static inline void TTPLPFC_HAL_resetProfilingGPIO2(void)
{
    #pragma diag_suppress = 770
    #pragma diag_suppress = 173
    HWREG(GPIODATA_BASE  + GPIO_O_GPACLEAR) = TTPLPFC_GPIO_PROFILING2_CLEAR;
    #pragma diag_warning = 770
    #pragma diag_warning = 173
}


static inline void TTPLPFC_HAL_gainHighSetforLowCurrent(void)
{
    GPIO_writePin(TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST, 1);
}


static inline void TTPLPFC_HAL_gainLowSetforHighCurrent(void)
{
    GPIO_writePin(TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST, 0);
}


static inline void TTPLPFC_HAL_closeRelay(void)
{
    GPIO_writePin(TTPLPFC_GPIO_RELAY, 1);
}


static inline void TTPLPFC_HAL_openRelay(void)
{
    GPIO_writePin(TTPLPFC_GPIO_RELAY, 0);
}

static inline void TTPLPFC_HAL_startLLC(void)
{
    //
    // Send a ping frame with frame tag 0000b
    //
    FSI_setTxFrameTag(FSITXA_BASE, FSI_FRAME_TAG1);
    FSI_setTxFrameType(FSITXA_BASE, FSI_FRAME_TYPE_PING);
    FSI_startTxTransmit(FSITXA_BASE); // Ping frame is sent here
}

static inline void TTPLPFC_HAL_shutdownLLC(void)
{
    //
    // Send a ping frame with frame tag 0000b
    //
    FSI_setTxFrameTag(FSITXA_BASE, FSI_FRAME_TAG2);
    FSI_setTxFrameType(FSITXA_BASE, FSI_FRAME_TYPE_PING);
    FSI_startTxTransmit(FSITXA_BASE); // Ping frame is sent here
}

static inline void TTPLPFC_HAL_lightUpLED2(void)
{
   GPIO_writePin(TTPLPFC_GPIO_LED2, 1);
}


static inline void TTPLPFC_HAL_clearPWMTripFlags(uint32_t base)
{
    //
    // clear all the configured trip sources for the PWM module
    //
    EPWM_clearTripZoneFlag(base,
                           ( EPWM_TZ_INTERRUPT_OST |
                             EPWM_TZ_INTERRUPT_CBC |
                             EPWM_TZ_INTERRUPT_DCAEVT1 )
                           );
}

static inline void TTPLPFC_HAL_clearOSTPWMTripFlag(uint32_t base)
{

    //
    // clear all the configured trip sources for the PWM module
    //
    EPWM_clearTripZoneFlag(base, EPWM_TZ_INTERRUPT_OST);
}

static inline void TTPLPFC_HAL_forceOSTPWMTrip(uint32_t base)
{
    EPWM_forceTripZoneEvent(base, EPWM_TZ_FORCE_EVENT_OST);
}


static inline void TTPLPFC_HAL_clearPWMInterruptFlag(uint32_t base)
{
    EPWM_clearEventTriggerInterruptFlag(base);
}


static inline void TTPLPFC_HAL_enablePWMInterruptGeneration(uint32_t base)
{
    EPWM_setCounterCompareValue(base, EPWM_COUNTER_COMPARE_B, 25);
    EPWM_setInterruptSource(base, EPWM_INT_TBCTR_D_CMPB);
    EPWM_setInterruptEventCount(base, TTPLPFC_CNTRL_ISR_FREQ_RATIO);
    EPWM_enableInterrupt(base);
    EPWM_clearEventTriggerInterruptFlag(base);
}

#ifndef __TMS320C28XX_CLA__

//
// disableAllFSIInterrupts - Disables all event interrupts in both FSI Tx/Rx,
//                           also clear them
//
static inline void TTPLPFC_HAL_disableAllFSIInterrupts(void)
{
    FSI_disableTxInterrupt(FSITXA_BASE, FSI_INT1, FSI_TX_EVTMASK);
    FSI_disableTxInterrupt(FSITXA_BASE, FSI_INT2, FSI_TX_EVTMASK);
    FSI_disableRxInterrupt(FSIRXA_BASE, FSI_INT1, FSI_RX_EVTMASK);
    FSI_disableRxInterrupt(FSIRXA_BASE, FSI_INT2, FSI_RX_EVTMASK);

    FSI_clearTxEvents(FSITXA_BASE, FSI_TX_EVTMASK);
    FSI_clearRxEvents(FSIRXA_BASE, FSI_RX_EVTMASK);
}

static inline void TTPLPFC_HAL_clearInterrupt(uint16_t pie_group_no)
{
    Interrupt_clearACKGroup(pie_group_no);
}

static inline void TTPLPFC_HAL_setupFsiInterrupt(void)
{
    //
    // Interrupts that are used in this example are re-mapped to ISR functions
    // found within this file. Total 4; FSI Tx/Rx :: INT1/INT2
    //
    Interrupt_register(INT_FSIRXA1, &fsiRxInt1ISR); // Ping frame ISR
    Interrupt_register(INT_FSIRXA2, &fsiRxInt2ISR);

    //
    // Enable FSI Tx/Rx interrupts
    //
    Interrupt_enable(INT_FSIRXA1);
    Interrupt_enable(INT_FSIRXA2);

    //
    // Enable Global Interrupt (INTM) and realtime interrupt (DBGM)
    //
    EINT;
    ERTM;

    //
    // Enable transmit/receive error events to be sent over INT2 line
    // Overrun and Underrun conditions in Rx are not enabled as buffer pointers
    // are always overwritten to first location for sending data frames.
    //
    FSI_enableRxInterrupt(FSIRXA_BASE, FSI_INT2, FSI_RX_EVT_CRC_ERR  |
                                                 FSI_RX_EVT_EOF_ERR  |
                                                 FSI_RX_EVT_TYPE_ERR);

    //
    // Enable normal data transfer events to be sent over INT1 line
    //
    FSI_enableRxInterrupt(FSIRXA_BASE, FSI_INT1, FSI_RX_EVT_DATA_FRAME);
}

static inline void TTPLPFC_HAL_setupInterrupt(void)
{
    CPUTimer_enableInterrupt(
            TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT_TRIG_CPUTIMER_BASE
            );
    CPUTimer_clearOverflowFlag(
            TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT_TRIG_CPUTIMER_BASE
            );

#if TTPLPFC_CONTROL_RUNNING_ON == C28x_CORE
    Interrupt_register(TTPLPFC_C28x_CONTROLISR_INTERRUPT, &ISR1);

    TTPLPFC_HAL_enablePWMInterruptGeneration(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE);

    TTPLPFC_HAL_clearInterrupt(
            TTPLPFC_C28x_CONTROLISR_INTERRUPT_PIE_GROUP_NO);

    Interrupt_enable(TTPLPFC_C28x_CONTROLISR_INTERRUPT);
#endif

#if TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON == C28x_CORE
    Interrupt_register(TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT, &ISR2);
    Interrupt_enable(TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT);
#endif


#if(TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE || TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON == CLA_CORE)
    TTPLPFC_HAL_setupCLA();
#endif

    EALLOW;

    //
    //Enable Global interrupt INTM.
    //Enable Global realtime interrupt DBGM
    //
    EINT;
    ERTM;
    EDIS;
}

#endif

#ifdef __cplusplus
}
#endif                                  /* extern "C" */


#endif
