//#############################################################################
//
// FILE:   ttplpfc_settings.h
//
// TITLE:  ttplpfc_settings.h
//
//#############################################################################
// $TI Release: $
// $Release Date: $
// Copyright (C) {2021} Texas Instruments Incorporated - http://www.ti.com/
// * ALL RIGHTS RESERVED*
//#############################################################################

#ifndef _TTPLPFC_PROJSETTINGS_H
#define _TTPLPFC_PROJSETTINGS_H

#ifdef __cplusplus

extern "C" {
#endif

//*****************************************************************************
//defines
//*****************************************************************************

/* Device Related Defines */
#define CPU_SYS_CLOCK (120*1000000)
#define PWMSYSCLOCK_FREQ (120*1000000)
#define ECAPSYSCLOCK_FREQ	(120*1000000)

//
// Project Options
// Labs for System check-out
// LAB 1:PFC Open Loop Check (DC Input)
// LAB 2:PFC Closed Current Loop Check (DC Input)
// LAB 3:PFC Closed Current Loop Check (AC Input)
// LAB 4:PFC Closed Voltage Loop Check (AC Input)
//
#define TTPLPFC_LAB 2

// 1 means control runs on C28x , otherwise it will run on CLA
#define C28x_CORE 1
#define CLA_CORE 2
#define TTPLPFC_CONTROL_RUNNING_ON 1

// Check system under DC condition (cleanest SFRA curves) 0 is FALSE, 1 is TRUE
#define TTPLPFC_DC_CHECK 1 

//Enable Disable Adaptive Deadtime
#define TTPLPFC_ADAPTIVE_DEADTIME 0

// set 1 to enable non linear voltage loop 0 to disable 
#define TTPLPFC_NON_LINEAR_VOLTAGE_LOOP 0

#if TTPLPFC_LAB == 1
#define TTPLPFC_CONTROL_RUNNING_ON 1
#define TTPLPFC_DC_CHECK 1
#define TTPLPFC_ADAPTIVE_DEADTIME 0
#define TTPLPFC_SFRA_TYPE 0
#endif

#if TTPLPFC_LAB == 2
#define TTPLPFC_CONTROL_RUNNING_ON 1
#define TTPLPFC_DC_CHECK 1
#define TTPLPFC_ADAPTIVE_DEADTIME 0
#define TTPLPFC_SFRA_TYPE 1
#endif

#if TTPLPFC_LAB == 3
#define TTPLPFC_CONTROL_RUNNING_ON 1
#define TTPLPFC_DC_CHECK 0
#define TTPLPFC_ADAPTIVE_DEADTIME 0
#define TTPLPFC_SFRA_TYPE 1
#endif

#if TTPLPFC_LAB == 4
#define TTPLPFC_CONTROL_RUNNING_ON 1
#define TTPLPFC_DC_CHECK 0
#define TTPLPFC_ADAPTIVE_DEADTIME 0
#define TTPLPFC_NON_LINEAR_VOLTAGE_LOOP 0
#define TTPLPFC_SFRA_TYPE 2
#endif
/* Power Stage Related Values*/
#define TTPLPFC_PFC_PWM_SWITCHING_FREQUENCY ((float32_t)100*1000)
#define TTPLPFC_PFC_PWM_PERIOD ((PWMSYSCLOCK_FREQ)/(TTPLPFC_PFC_PWM_SWITCHING_FREQUENCY))

#define TTPLPFC_PFC_DEADBAND_RED_HS_US (float32_t) 0.1
#define TTPLPFC_PFC_DEADBAND_FED_HS_US (float32_t) 0.1

#define TTPLPFC_HIGH_FREQ_PWM_DEADBAND_FED_COUNT (int)((float32_t)TTPLPFC_PFC_DEADBAND_FED_HS_US*(float32_t)PWMSYSCLOCK_FREQ*(float32_t)0.000001)
#define TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_COUNT (int)((float32_t)TTPLPFC_PFC_DEADBAND_RED_HS_US*(float32_t)PWMSYSCLOCK_FREQ*(float32_t)0.000001)

#define TTPLPFC_VAC_MAX_SENSE_VOLT       (float32_t) 462.66
#define TTPLPFC_VDCBUS_MAX_SENSE_VOLT    (float32_t) 462.66
#define TTPLPFC_IL_MAX_SENSE_AMPS         (float32_t) 24.95
#define TTPLPFC_IL_TRIP_LIMIT_AMPS        (float32_t) 22
#define TTPLPFC_VAC_TYPICAL_VOLT         (float32_t) 120

#define TTPLPFC_VBUS_TYPICAL_VOLT 		(float32_t) 380

#define TTPLPFC_PFC_INDUCTOR_VALUE  ((float32_t)0.3*0.001)

/* Control Loop Design */
#define TTPLPFC_CONTROL_ISR_FREQUENCY ((TTPLPFC_PFC_PWM_SWITCHING_FREQUENCY)/(TTPLPFC_CNTRL_ISR_FREQ_RATIO))
#define	TTPLPFC_CNTRL_ISR_FREQ_RATIO	1
#define TTPLPFC_VOLTAGE_LOOP_RUN_RATIO	1

//SFRA Options 	
#define TTPLPFC_SFRA_DISABLED 0
#define TTPLPFC_SFRA_CURRENT  1
#define TTPLPFC_SFRA_VOLTAGE  2

#define TTPLPFC_SFRA_TYPE	1
#if TTPLPFC_SFRA_TYPE == TTPLPFC_SFRA_CURRENT
#define TTPLPFC_SFRA_ISR_FREQ       TTPLPFC_CONTROL_ISR_FREQUENCY
#else
#define TTPLPFC_SFRA_ISR_FREQ       TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY
#endif

#define PI_VALUE (float32_t) 3.141592653589

#define TTPLPFC_GI_PI_KP	(float32_t) 0.3496503407
#define TTPLPFC_GI_PI_KI	(float32_t) 0.0020000510

#define TTPLPFC_GV_PI_KP	(float32_t) 0.6004499882
#define TTPLPFC_GV_PI_KI	(float32_t) 0.0001000236

//=============================================================================
// User code settings file
//=============================================================================
#include "ttplpfc_user_settings.h"

#ifdef __cplusplus
}
#endif                                  /* extern "C" */

#endif //_PROJSETTINGS_H
