//#############################################################################
//
// FILE:   ttplpfc_user_settings.h
//
// TITLE:  ttplpfc User Settings
//
//#############################################################################
// $TI Release: TIDA_010062 v2.02.00.00 $
// $Release Date: Fri Oct  6 19:11:54 CDT 2023 $
// $Copyright:
// Copyright (C) 2023 Texas Instruments Incorporated - http://www.ti.com/
//
// ALL RIGHTS RESERVED
// $
//#############################################################################

//
// Defines
//
#define TTPLPFC_GI_PI_KP_CLAL    ((float32_t) 0.75)//1 0.05 CLAPI
#define TTPLPFC_GI_PI_KI_CLAL    ((float32_t) 0.0375)
#define TTPLPFC_GI_PI_KP_CLAH    ((float32_t) 0.5)
#define TTPLPFC_GI_PI_KI_CLAH    ((float32_t) 0.025)

#define TTPLPFC_GI_PI_MAX   ((float32_t) 1.0)
#define TTPLPFC_GI_PI_MIN   ((float32_t) -1.0)

#define TTPLPFC_GV_PI_MAX   ((float32_t) 0.7)
#define TTPLPFC_GV_PI_MIN   ((float32_t) -0.02)

#if TTPLPFC_CONTROL_RUNNING_ON == CLA_CORE
#define TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON CLA_CORE
#else
#define TTPLPFC_INSTRUMENTATION_ISR_RUNNING_ON C28x_CORE
#endif

#define F28004X 1
#define F28002X 2
#define TTPLPFC_DEBUG_CHIP 2

// FSI clock
#define TTPLPFC_PRESCALER_VAL    FSI_PRESCALE_30MHZ
#define TTPLPFC_FSI_ISR 1

/*************************Interrupt related************************/
#define TTPLPFC_C28x_CONTROLISR_INTERRUPT_PIE_GROUP_NO INTERRUPT_ACK_GROUP3
#define TTPLPFC_C28x_TENKHZISR_INTERRUPT_PIE_GROUP_NO INTERRUPT_CPU_INT14

#define TTPLPFC_C28x_CONTROLISR_INTERRUPT_TRIG_PWM_BASE EPWM1_BASE
#define TTPLPFC_C28x_CONTROLISR_INTERRUPT INT_EPWM1

#define TTPLPFC_INSTRUMENTATION_ISR_FREQUENCY 10000
#define TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT_TRIG_CPUTIMER_BASE CPUTIMER2_BASE
#define TTPLPFC_C28x_INSTRUMENTATION_INTERRUPT INT_TIMER2

#define TTPLPFC_CLA_CONTROLISR_TRIG  CLA_TRIGGER_EPWM1INT
#define TTPLPFC_CLA_INSTRUMENTATIONISR_TRIG  CLA_TRIGGER_TINT2

//
//Non-linear voltage loop Kp multiplier
//
#define TTPLPFC_NON_LINEAR_V_LOOP_KP_MULTIPLIER ((float32_t) 5.0)

/*************************REF Compensation related************************/
#define TTPLPFC_INPUT_CAP_COMPENSATION           1
#define TTPLPFC_HIGH_LINE_INPUT_CAP_COMP_ADJUST ((float32_t)-0.006)
#define TTPLPFC_LOW_LINE_INPUT_CAP_COMP_ADJUST  ((float32_t)-0.003)

/******************************SPLL related******************************/
#define TTPLPFC_SPLL_1PH_NOTCH_SEL      1
#define TTPLPFC_SPLL_1PH_SOGI_SEL       2
#define TTPLPFC_SPLL_1PH_SOGI_FLL_SEL   3
#define TTPLPFC_SPLL_METHOD_SELECT      TTPLPFC_SPLL_1PH_SOGI_SEL

#define TTPLPFC_AC_FREQ 60

/* PWM pin, ADC, SDFM, Relay Selection related variables */
/******************************EPWM related******************************/
//
//EPWM1 is for LF_MOSH/L, EPWM3 is for PFCG_1H/L
//
#define TTPLPFC_LOW_FREQ_PWM_BASE                   EPWM1_BASE
#define TTPLPFC_LOW_FREQ_PWM_H_GPIO                 0
#define TTPLPFC_LOW_FREQ_PWM_H_GPIO_PIN_CONFIG      GPIO_0_EPWM1_A
#define TTPLPFC_LOW_FREQ_PWM_L_GPIO                 1
#define TTPLPFC_LOW_FREQ_PWM_L_GPIO_PIN_CONFIG      GPIO_1_EPWM1_B

#define TTPLPFC_HIGH_FREQ_PWM_BASE                  EPWM3_BASE
#define TTPLPFC_HIGH_FREQ_PWM_H_GPIO                4
#define TTPLPFC_HIGH_FREQ_PWM_H_GPIO_PIN_CONFIG     GPIO_4_EPWM3_A
#define TTPLPFC_HIGH_FREQ_PWM_L_GPIO                5
#define TTPLPFC_HIGH_FREQ_PWM_L_GPIO_PIN_CONFIG     GPIO_5_EPWM3_B

#define TTPLPFC_PFC_DEADBAND_RED_MIN_US 0.020 // 20ns
#define TTPLPFC_PFC_DEADBAND_RED_MAX_US 0.200 // 200ns

#define TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_MAX_COUNT (int)((float32_t)TTPLPFC_PFC_DEADBAND_RED_MAX_US * (float32_t)PWMSYSCLOCK_FREQ * (float32_t)0.000001)
#define TTPLPFC_HIGH_FREQ_PWM_DEADBAND_RED_MIN_COUNT (int)((float32_t)TTPLPFC_PFC_DEADBAND_RED_MIN_US * (float32_t)PWMSYSCLOCK_FREQ * (float32_t)0.000001)

#define TTPLPFC_GAN_COSS  0.000000000145
/******************************ADC related******************************/
//
//A4-->ACN_SENSE TTPLPFC_VACN_ADC
//
#define TTPLPFC_VACN_ADC_MODULE          ADCA_BASE
#define TTPLPFC_VACN_ADC_SOC_NO_1        ADC_SOC_NUMBER0
#define TTPLPFC_VACN_ADC_SOC_NO_2        ADC_SOC_NUMBER1
#define TTPLPFC_VACN_ADC_PIN             ADC_CH_ADCIN4
#define TTPLPFC_VACN_ADC_TRIG_SOURCE_1   ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VACN_ADC_TRIG_SOURCE_2   ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VACN_ADC_ACQPS_SYS_CLKS  20
#define TTPLPFC_VACN_ADCRESULTREGBASE    ADCARESULT_BASE

//
//B4-->ACL_SENSE
//
#define TTPLPFC_VACL_ADC_MODULE          ADCB_BASE
#define TTPLPFC_VACL_ADC_SOC_NO_1        ADC_SOC_NUMBER0
#define TTPLPFC_VACL_ADC_SOC_NO_2        ADC_SOC_NUMBER1
#define TTPLPFC_VACL_ADC_PIN             ADC_CH_ADCIN4
#define TTPLPFC_VACL_ADC_TRIG_SOURCE_1   ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VACL_ADC_TRIG_SOURCE_2   ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VACL_ADC_ACQPS_SYS_CLKS  20
#define TTPLPFC_VACL_ADCRESULTREGBASE    ADCBRESULT_BASE

//
//B3-->AC_CUR_VREF for Iac_ref
//
#define TTPLPFC_IL_VREF_ADC_MODULE           ADCB_BASE
#define TTPLPFC_IL_VREF_ADC_SOC_NO_1         ADC_SOC_NUMBER2
#define TTPLPFC_IL_VREF_ADC_SOC_NO_2         ADC_SOC_NUMBER3
#define TTPLPFC_IL_VREF_ADC_PIN              ADC_CH_ADCIN3
#define TTPLPFC_IL_VREF_ADC_TRIG_SOURCE_1    ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_IL_VREF_ADC_TRIG_SOURCE_2    ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_IL_VREF_ADC_ACQPS_SYS_CLKS   20
#define TTPLPFC_IL_VREF_ADCRESULTREGBASE     ADCBRESULT_BASE

//
//C2-->amplifier AC_CUR_SENS for Iin_sense
//
#define TTPLPFC_IL_ADC_MODULE           ADCC_BASE
#define TTPLPFC_IL_ADC_SOC_NO_1         ADC_SOC_NUMBER0
#define TTPLPFC_IL_ADC_SOC_NO_2         ADC_SOC_NUMBER1
#define TTPLPFC_IL_ADC_PIN              ADC_CH_ADCIN2
#define TTPLPFC_IL_ADC_TRIG_SOURCE_1    ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_IL_ADC_TRIG_SOURCE_2    ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_IL_ADC_ACQPS_SYS_CLKS   20
#define TTPLPFC_IL_ADCRESULTREGBASE     ADCCRESULT_BASE

//
//B11-->VBUS-sense
//
#define TTPLPFC_VBUS_ADC_MODULE         ADCB_BASE
#define TTPLPFC_VBUS_ADC_SOC_NO_1       ADC_SOC_NUMBER2
#define TTPLPFC_VBUS_ADC_SOC_NO_2       ADC_SOC_NUMBER3
#define TTPLPFC_VBUS_ADC_PIN            ADC_CH_ADCIN11
#define TTPLPFC_VBUS_ADC_TRIG_SOURCE_1  ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VBUS_ADC_TRIG_SOURCE_2  ADC_TRIGGER_EPWM3_SOCA
#define TTPLPFC_VBUS_ADC_ACQPS_SYS_CLKS 20
#define TTPLPFC_VBUS_ADCRESULTREGBASE   ADCBRESULT_BASE

/******************************OCP related******************************/
#define TTPLPFC_BOARD_PROTECTION_IL 1

#define TTPLPFC_BOARD_PROTECTION_IL_CMPSS_BASE               CMPSS3_BASE
#define TTPLPFC_BOARD_PROTECTION_IL_CMPSS_ASYSCTRL_CMPHPMUX  ASYSCTL_CMPHPMUX_SELECT_3
#define TTPLPFC_BOARD_PROTECTION_IL_CMPSS_ASYSCTRL_CMPLPMUX  ASYSCTL_CMPLPMUX_SELECT_3
#define TTPLPFC_BOARD_PROTECTION_IL_CMPSS_ASYSCTRL_MUX_VALUE 0

#define TTPLPFC_BOARD_PROTECTION_IL_XBAR_MUX                 XBAR_MUX04
#define TTPLPFC_BOARD_PROTECTION_IL_XBAR_MUX_VAL             XBAR_EPWM_MUX04_CMPSS3_CTRIPH_OR_L

/******************************GPIO Related******************************/
#define TTPLPFC_GPIO_PROFILING1              9
#define TTPLPFC_GPIO_PROFILING1_SET          GPIO_GPASET_GPIO9
#define TTPLPFC_GPIO_PROFILING1_CLEAR        GPIO_GPACLEAR_GPIO9
#define TTPLPFC_GPIO_PROFILING1_PIN_CONFIG   GPIO_9_GPIO9

#define TTPLPFC_GPIO_PROFILING2              14
#define TTPLPFC_GPIO_PROFILING2_SET          GPIO_GPASET_GPIO14
#define TTPLPFC_GPIO_PROFILING2_CLEAR        GPIO_GPACLEAR_GPIO14
#define TTPLPFC_GPIO_PROFILING2_PIN_CONFIG   GPIO_14_GPIO14

#define TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST     15
#define TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST_SET     GPIO_GPASET_GPIO15
#define TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST_CLEAR   GPIO_GPACLEAR_GPIO15
#define TTPLPFC_GPIO_I_SENSE_GAIN_ADJUST_PIN_CONFIG GPIO_15_GPIO15

#define TTPLPFC_GPIO_RELAY                   16
#define TTPLPFC_GPIO_RELAY_SET               GPIO_GPASET_GPIO16
#define TTPLPFC_GPIO_RELAY_CLEAR             GPIO_GPACLEAR_GPIO16
#define TTPLPFC_GPIO_RELAY_PIN_CONFIG        GPIO_16_GPIO16

#define TTPLPFC_GPIO_LED1                    31
#define TTPLPFC_GPIO_LED1_SET                GPIO_GPASET_GPIO31
#define TTPLPFC_GPIO_LED1_CLEAR              GPIO_GPACLEAR_GPIO31
#define TTPLPFC_GPIO_LED1_PIN_CONFIG         GPIO_31_GPIO31

#define TTPLPFC_GPIO_LED2                    34
#define TTPLPFC_GPIO_LED2_SET                GPIO_GPASET_GPIO34
#define TTPLPFC_GPIO_LED2_CLEAR              GPIO_GPACLEAR_GPIO34
#define TTPLPFC_GPIO_LED2_PIN_CONFIG         GPIO_34_GPIO34


//
// SFRA related
//
#define TTPLPFC_SFRA_GUI_SCI_BASE               SCIA_BASE
#define TTPLPFC_SCI_VBUS_CLK                    30000000
#define TTPLPFC_SFRA_GUI_SCI_BAUDRATE           57600
#define TTPLPFC_SFRA_GUI_SCIRX_GPIO             28
#define TTPLPFC_SFRA_GUI_SCITX_GPIO             29
#define TTPLPFC_SFRA_GUI_SCIRX_GPIO_PIN_CONFIG  GPIO_28_SCIA_RX
#define TTPLPFC_SFRA_GUI_SCITX_GPIO_PIN_CONFIG  GPIO_29_SCIA_TX

//
// if the following #define is set to 1 SFRA GUI indicates status on LED
// otherwise LED code is ignored
// check sfra_gui_scicomms_driverlib.c file for defines used by SCI CommsSFRA GUI
//
#define TTPLPFC_SFRA_GUI_LED_INDICATOR 1
#define TTPLPFC_SFRA_GUI_LED_GPIO 31
#define TTPLPFC_SFRA_GUI_LED_GPIO_PIN_CONFIG GPIO_31_GPIO31

//
// End of File
//
